@@ -14,7 +14,7 @@ import javax.inject.Inject;
 import javax.inject.Singleton;
 
 import org.ovirt.engine.core.common.VdcObjectType;
-import org.ovirt.engine.core.common.action.VdcActionType;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.job.Job;
 import org.ovirt.engine.core.common.job.JobExecutionStatus;
 import org.ovirt.engine.core.common.job.Step;
@@ -24,7 +24,6 @@ import org.ovirt.engine.core.dao.JobDao;
 import org.ovirt.engine.core.dao.JobSubjectEntityDao;
 import org.ovirt.engine.core.dao.StepDao;
 import org.ovirt.engine.core.dao.StepSubjectEntityDao;
-import org.ovirt.engine.core.utils.collections.MultiValueMapUtils;
 import org.ovirt.engine.core.utils.transaction.TransactionSupport;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -161,7 +160,7 @@ public class JobRepositoryImpl implements JobRepository {
             if (step.getParentStepId() == null) {
                 jobDirectSteps.add(step);
             } else {
-                MultiValueMapUtils.addToMap(step.getParentStepId(), step, parentStepMap);
+                parentStepMap.computeIfAbsent(step.getParentStepId(), k -> new ArrayList<>()).add(step);
             }
         }
 
@@ -183,7 +182,7 @@ public class JobRepositoryImpl implements JobRepository {
     }
 
     @Override
-    public List<Job> getJobsByEntityAndAction(Guid entityId, VdcActionType actionType) {
+    public List<Job> getJobsByEntityAndAction(Guid entityId, ActionType actionType) {
         List<Job> jobList = new ArrayList<>();
         List<Guid> jobIdsList = jobSubjectEntityDao.getJobIdByEntityId(entityId);
 
