@@ -2,9 +2,8 @@ package org.ovirt.engine.core.bll;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.mock;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
@@ -16,16 +15,15 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.ovirt.engine.core.bll.context.CommandContext;
 import org.ovirt.engine.core.bll.interfaces.BackendInternal;
 import org.ovirt.engine.core.bll.utils.PermissionSubject;
 import org.ovirt.engine.core.common.AuditLogType;
 import org.ovirt.engine.core.common.VdcObjectType;
-import org.ovirt.engine.core.common.action.CpuProfileParameters;
+import org.ovirt.engine.core.common.action.ActionReturnValue;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.ManagementNetworkOnClusterOperationParameters;
-import org.ovirt.engine.core.common.action.VdcActionType;
-import org.ovirt.engine.core.common.action.VdcReturnValueBase;
 import org.ovirt.engine.core.common.businessentities.ArchitectureType;
 import org.ovirt.engine.core.common.businessentities.Cluster;
 import org.ovirt.engine.core.common.businessentities.MacPool;
@@ -115,10 +113,7 @@ public class AddClusterCommandTest extends BaseCommandTest {
     }
 
     private void mockBackend() {
-        VdcReturnValueBase addClusterReturnValue = mock(VdcReturnValueBase.class);
-        when(addClusterReturnValue.getSucceeded()).thenReturn(true);
-
-        when(backend.runAction(any(VdcActionType.class), any(CpuProfileParameters.class))).thenReturn(addClusterReturnValue);
+        when(backend.runAction(any(), any())).thenReturn(new ActionReturnValue());
     }
 
     @Test
@@ -126,7 +121,7 @@ public class AddClusterCommandTest extends BaseCommandTest {
         addClusterCommand.executeCommand();
 
         verify(clusterDao).save(cluster);
-        verify(backend).runAction(eq(VdcActionType.AddCpuProfile), any(CpuProfileParameters.class));
+        verify(backend).runAction(eq(ActionType.AddCpuProfile), any());
 
         assertTrue(addClusterCommand.getReturnValue().getSucceeded());
     }
