@@ -8,27 +8,23 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.Mock;
 import org.mockito.Spy;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.ovirt.engine.core.bll.validator.VmValidator;
 import org.ovirt.engine.core.common.action.MigrateVmParameters;
 import org.ovirt.engine.core.common.businessentities.VM;
 import org.ovirt.engine.core.common.errors.EngineMessage;
 import org.ovirt.engine.core.compat.Guid;
-import org.ovirt.engine.core.dal.dbbroker.DbFacade;
 
 @RunWith(MockitoJUnitRunner.class)
 public class MigrateVmCommandTest {
 
     private Guid vmId = Guid.newGuid();
 
-    @Mock
-    DbFacade dbFacade;
-
     @Mock
     VmValidator vmValidator;
 
     @Spy
-    MigrateVmCommand command = new MigrateVmCommand<>(new MigrateVmParameters(false, vmId), null);
+    private MigrateVmCommand<MigrateVmParameters> command = new MigrateVmCommand<>(new MigrateVmParameters(false, vmId), null);
 
 
     @Before
