@@ -2,10 +2,9 @@ package org.ovirt.engine.core.bll.gluster;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.doReturn;
-import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.verifyZeroInteractions;
@@ -33,7 +32,6 @@ import org.ovirt.engine.core.common.businessentities.gluster.MemoryStatus;
 import org.ovirt.engine.core.common.businessentities.gluster.Mempool;
 import org.ovirt.engine.core.common.queries.gluster.GlusterVolumeAdvancedDetailsParameters;
 import org.ovirt.engine.core.common.vdscommands.VDSCommandType;
-import org.ovirt.engine.core.common.vdscommands.VDSParametersBase;
 import org.ovirt.engine.core.common.vdscommands.VDSReturnValue;
 import org.ovirt.engine.core.compat.Guid;
 import org.ovirt.engine.core.dao.VdsDao;
@@ -49,6 +47,8 @@ public class GetGlusterVolumeAdvancedDetailsQueryTest extends
     private static final Guid SERVER_ID = Guid.newGuid();
     private static final String SERVER_NAME = "server1";
     private GlusterVolumeAdvancedDetails expectedVolumeAdvancedDetails;
+
+    @Mock
     private GlusterUtil glusterUtils;
 
     @Mock
@@ -155,8 +155,6 @@ public class GetGlusterVolumeAdvancedDetailsQueryTest extends
     }
 
     private void setupMock() {
-        glusterUtils = mock(GlusterUtil.class);
-
         when(volumeDao.getById(VOLUME_ID)).thenReturn(getVolume());
         when(brickDao.getById(BRICK_ID)).thenReturn(getBrick());
 
@@ -168,8 +166,7 @@ public class GetGlusterVolumeAdvancedDetailsQueryTest extends
         VDSReturnValue returnValue = new VDSReturnValue();
         returnValue.setSucceeded(true);
         returnValue.setReturnValue(expectedVolumeAdvancedDetails);
-        doReturn(returnValue).when(getQuery()).runVdsCommand(eq(VDSCommandType.GetGlusterVolumeAdvancedDetails),
-                any(VDSParametersBase.class));
+        doReturn(returnValue).when(getQuery()).runVdsCommand(eq(VDSCommandType.GetGlusterVolumeAdvancedDetails), any());
     }
 
     @Test
@@ -201,7 +198,6 @@ public class GetGlusterVolumeAdvancedDetailsQueryTest extends
     public void testQueryForNullBrickId() {
         doReturn(VOLUME_ID).when(getQueryParameters()).getVolumeId();
         doReturn(null).when(getQueryParameters()).getBrickId();
-        doReturn(glusterUtils).when(getQuery()).getGlusterUtils();
         doReturn(getVds(VDSStatus.Up)).when(glusterUtils).getRandomUpServer(CLUSTER_ID);
 
         getQuery().executeQueryCommand();
