@@ -2,21 +2,20 @@ package org.ovirt.engine.core.bll.storage;
 
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
+import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
-
-import java.util.Collections;
+import static org.mockito.Mockito.withSettings;
 
 import org.junit.Before;
 import org.junit.ClassRule;
 import org.junit.Test;
+import org.mockito.Answers;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
 import org.ovirt.engine.core.bll.BaseCommandTest;
 import org.ovirt.engine.core.common.action.StoragePoolManagementParameter;
 import org.ovirt.engine.core.common.businessentities.StoragePool;
 import org.ovirt.engine.core.common.config.ConfigValues;
-import org.ovirt.engine.core.common.errors.EngineMessage;
 import org.ovirt.engine.core.compat.Guid;
 import org.ovirt.engine.core.dao.StoragePoolDao;
 import org.ovirt.engine.core.dao.StoragePoolIsoMapDao;
@@ -25,8 +24,10 @@ import org.ovirt.engine.core.utils.MockConfigRule;
 public class StorageHandlingCommandBaseTest extends BaseCommandTest {
 
     @InjectMocks
-    private StorageHandlingCommandBase<StoragePoolManagementParameter> cmd =
-            new TestStorageHandlingCommandBase(new StoragePoolManagementParameter(createStoragePool()));
+    private StorageHandlingCommandBase<StoragePoolManagementParameter> cmd = mock(
+            StorageHandlingCommandBase.class,
+            withSettings().defaultAnswer(Answers.CALLS_REAL_METHODS)
+                    .useConstructor(new StoragePoolManagementParameter(createStoragePool()), null));
 
     @Mock
     private StoragePoolDao storagePoolDao;
@@ -45,24 +46,6 @@ public class StorageHandlingCommandBaseTest extends BaseCommandTest {
         cmd.init();
 
         when(storagePoolDao.get(storagePool.getId())).thenReturn(storagePool);
-        when(storagePoolIsoMapDao.getAllForStorage(any(Guid.class))).thenReturn(Collections.emptyList());
-    }
-
-    @Test
-    public void storagePoolNotFound() {
-        when(storagePoolDao.get(storagePool.getId())).thenReturn(null);
-        checkStoragePoolFails();
-    }
-
-    @Test
-    public void storagePoolNull() {
-        createCommandWithNullPool();
-        checkStoragePoolFails();
-    }
-
-    @Test
-    public void storagePoolExists() {
-        checkStoragePoolSucceeds();
     }
 
     @Test
@@ -77,10 +60,6 @@ public class StorageHandlingCommandBaseTest extends BaseCommandTest {
         checkStoragePoolNameLengthFails();
     }
 
-    private void checkStoragePoolSucceeds() {
-        assertTrue(cmd.checkStoragePool());
-    }
-
     private static StoragePool createStoragePool() {
         StoragePool pool = new StoragePool();
         pool.setName("DefaultStoragePool");
@@ -89,14 +68,10 @@ public class StorageHandlingCommandBaseTest extends BaseCommandTest {
         return pool;
     }
 
-    private void checkStoragePoolFails() {
-        assertFalse(cmd.checkStoragePool());
-        assertTrue(cmd.getReturnValue().getValidationMessages().contains(EngineMessage
-                .ACTION_TYPE_FAILED_STORAGE_POOL_NOT_EXIST.toString()));
-    }
-
     private void createCommandWithNullPool() {
-        cmd = new TestStorageHandlingCommandBase(new StoragePoolManagementParameter());
+        cmd = mock(StorageHandlingCommandBase.class,
+                withSettings().defaultAnswer(Answers.CALLS_REAL_METHODS)
+                        .useConstructor(new StoragePoolManagementParameter(), null));
     }
 
     private static void setAcceptableNameLength(final int length) {
@@ -110,15 +85,4 @@ public class StorageHandlingCommandBaseTest extends BaseCommandTest {
     private void checkStoragePoolNameLengthFails() {
         assertTrue(cmd.checkStoragePoolNameLengthValid());
     }
-
-    private static class TestStorageHandlingCommandBase extends StorageHandlingCommandBase<StoragePoolManagementParameter> {
-        TestStorageHandlingCommandBase(StoragePoolManagementParameter parameters) {
-            super(parameters, null);
-        }
-
-        @Override
-        protected void executeCommand() {
-            // Intentionally empty - no behavior is required
-        }
-    }
 }
