@@ -2,7 +2,7 @@ package org.ovirt.engine.core.bll.storage.disk;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.when;
 
@@ -81,7 +81,7 @@ public class GetAllDisksByVmIdQueryTest extends AbstractUserQueryTest<IdQueryPar
 
         when(diskDaoMock.getAllForVm(vmID, getUser().getId(), getQueryParameters().isFiltered())).thenReturn(returnArray);
 
-        when(diskVmElementDao.get(any(VmDeviceId.class))).thenReturn(new DiskVmElement(new VmDeviceId()));
+        when(diskVmElementDao.get(any())).thenReturn(new DiskVmElement(new VmDeviceId()));
 
         // Snapshots
         doReturn(new ArrayList<>(Collections.nCopies(NUM_DISKS_OF_EACH_KIND,
