@@ -19,7 +19,7 @@ import org.ovirt.engine.core.compat.Guid;
  * <li>Any additional devices which were relevant</li>
  * </ul>
  */
-public class Snapshot implements IVdcQueryable, BusinessEntityWithStatus<Guid, Snapshot.SnapshotStatus> {
+public class Snapshot implements Queryable, BusinessEntityWithStatus<Guid, Snapshot.SnapshotStatus> {
 
     /**
      * Needed for java serialization/deserialization mechanism.
@@ -303,7 +303,7 @@ public class Snapshot implements IVdcQueryable, BusinessEntityWithStatus<Guid, S
         IN_PREVIEW
     }
 
-    public static enum SnapshotType {
+    public enum SnapshotType {
         REGULAR,
         ACTIVE,
         STATELESS,
