@@ -11,24 +11,52 @@ import java.util.Arrays;
 import java.util.List;
 
 import org.junit.Test;
+import org.ovirt.engine.core.common.businessentities.BusinessEntity;
 import org.ovirt.engine.core.common.businessentities.GuestAgentStatus;
 import org.ovirt.engine.core.common.businessentities.VMStatus;
 import org.ovirt.engine.core.common.businessentities.VmDynamic;
 import org.ovirt.engine.core.compat.Guid;
 
-public class VmDynamicDaoTest extends BaseDaoTestCase {
-    private static final Guid VDS_STATIC_ID = new Guid("afce7a39-8e8c-4819-ba9c-796d316592e6");
-    private static final Guid VDS_STATIC_ID2 = new Guid("23f6d691-5dfb-472b-86dc-9e1d2d3c18f3");
+public class VmDynamicDaoTest extends BaseGenericDaoTestCase<Guid, VmDynamic, VmDynamicDao> {
     private static final int DYNAMIC_RUNNING_COUNT = 3;
-    private VmDynamicDao dao;
-    private VmDynamic existingVm;
+
+    /**
+     * Test the {@link VmDynamicDao#save(BusinessEntity)} method by adding a vm_dynamic record to a template.
+     * While this doesn't make any sense from a business logic perspective, it's perfectly legal from a database
+     * perspective, and helps avoid dependencies on the {@link VmDynamicDao#remove(Guid)} method.
+     */
+    @Override
+    protected VmDynamic generateNewEntity() {
+        VmDynamic newEntity = new VmDynamic();
+        newEntity.setId(FixturesTool.VM_TEMPLATE_RHEL5);
+        newEntity.setStatus(VMStatus.NotResponding);
+        return newEntity;
+    }
 
     @Override
-    public void setUp() throws Exception {
-        super.setUp();
-        dao = dbFacade.getVmDynamicDao();
-        existingVm = dao.get(new Guid("77296e00-0cad-4e5a-9299-008a7b6f4355"));
-        existingVm.setStatus(VMStatus.Up);
+    protected void updateExistingEntity() {
+        existingEntity.setVmHost("farkle.redhat.com");
+        existingEntity.setRunOnce(!existingEntity.isRunOnce());
+    }
+
+    @Override
+    protected Guid getExistingEntityId() {
+        return FixturesTool.VM_RHEL5_POOL_57;
+    }
+
+    @Override
+    protected VmDynamicDao prepareDao() {
+        return dbFacade.getVmDynamicDao();
+    }
+
+    @Override
+    protected Guid generateNonExistingId() {
+        return Guid.newGuid();
+    }
+
+    @Override
+    protected int getEntitiesTotalCount() {
+        return 8;
     }
 
     /**
@@ -36,19 +64,19 @@ public class VmDynamicDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetAllForRunningForVds() {
-        List<VmDynamic> result = dao.getAllRunningForVds(VDS_STATIC_ID);
+        List<VmDynamic> result = dao.getAllRunningForVds(FixturesTool.VDS_RHEL6_NFS_SPM);
         assertNotNull(result);
         assertFalse(result.isEmpty());
         assertEquals(DYNAMIC_RUNNING_COUNT, result.size());
         for (VmDynamic vmdynamic : result) {
-            assertEquals(VDS_STATIC_ID, vmdynamic.getRunOnVds());
+            assertEquals(FixturesTool.VDS_RHEL6_NFS_SPM, vmdynamic.getRunOnVds());
         }
     }
 
     @Test
     public void testIsAnyVmRunOnVds() {
-        assertTrue(dao.isAnyVmRunOnVds(VDS_STATIC_ID));
-        assertFalse(dao.isAnyVmRunOnVds(VDS_STATIC_ID2));
+        assertTrue(dao.isAnyVmRunOnVds(FixturesTool.VDS_RHEL6_NFS_SPM));
+        assertFalse(dao.isAnyVmRunOnVds(FixturesTool.GLUSTER_BRICK_SERVER1));
     }
 
     /**
@@ -56,79 +84,22 @@ public class VmDynamicDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testUpdateStatus() {
-        VmDynamic before = dao.get(existingVm.getId());
-        before.setStatus(VMStatus.Down);
-        dao.updateStatus(before.getId(), before.getStatus());
-        VmDynamic after = dao.get(existingVm.getId());
-        assertEquals(before, after);
-    }
-
-    /**
-     * Ensures that null is returned when the id is invalid.
-     */
-    @Test
-    public void testGetWithInvalidId() {
-        VmDynamic result = dao.get(Guid.newGuid());
-        assertNull(result);
-    }
-
-    @Test
-    public void testGet() {
-        VmDynamic result = dao.get(existingVm.getId());
-        assertNotNull(result);
-        assertEquals(existingVm.getId(), result.getId());
-    }
-
-    @Test
-    public void testSave() {
-        dao.remove(existingVm.getId());
-        dao.save(existingVm);
-        VmDynamic vmdynamic = dao.get(existingVm.getId());
-
-        assertNotNull(vmdynamic);
-        assertEquals(vmdynamic, existingVm);
-    }
-
-    /**
-     * Ensures deleting the dynamic portion of a VM works.
-     */
-    @Test
-    public void testRemoveDynamic() {
-        VmDynamic before = dao.get(existingVm.getId());
-
-        // make sure we're using a real example
-        assertNotNull(before);
-        dao.remove(existingVm.getId());
-        VmDynamic after = dao.get(existingVm.getId());
-        assertNull(after);
-    }
-
-    /**
-     * Ensures updating the dynamic aspect of the VM works.
-     */
-    @Test
-    public void testUpdate() {
-        VmDynamic before = dao.get(existingVm.getId());
-
-        before.setVmHost("farkle.redhat.com");
-        before.setRunOnce(!before.isRunOnce());
-        dao.update(before);
-
-        VmDynamic after = dao.get(existingVm.getId());
-
-        assertEquals(before, after);
+        existingEntity.setStatus(VMStatus.Down);
+        dao.updateStatus(existingEntity.getId(), existingEntity.getStatus());
+        VmDynamic after = dao.get(existingEntity.getId());
+        assertEquals(existingEntity, after);
     }
 
     @Test
     public void testUpdateAll() throws Exception {
-        VmDynamic existingVm2 = dao.get(new Guid("77296e00-0cad-4e5a-9299-008a7b6f4356"));
-        existingVm.setStatus(VMStatus.Down);
+        VmDynamic existingVm2 = dao.get(FixturesTool.VM_RHEL5_POOL_51);
+        existingEntity.setStatus(VMStatus.Down);
         existingVm2.setIp("111");
         existingVm2.setFqdn("localhost.localdomain");
 
-        dao.updateAll(Arrays.asList(existingVm, existingVm2));
+        dao.updateAll(Arrays.asList(existingEntity, existingVm2));
 
-        assertEquals(existingVm, dao.get(existingVm.getId()));
+        assertEquals(existingEntity, dao.get(existingEntity.getId()));
         assertEquals(existingVm2, dao.get(existingVm2.getId()));
     }
 
@@ -138,7 +109,7 @@ public class VmDynamicDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testUpdateConsoleUserWithOptimisticLockingSuccess() throws Exception {
-        VmDynamic vmWithoutConsoleUser = dao.get(new Guid("77296e00-0cad-4e5a-9299-008a7b6f4356"));
+        VmDynamic vmWithoutConsoleUser = dao.get(FixturesTool.VM_RHEL5_POOL_51);
         vmWithoutConsoleUser.setConsoleUserId(new Guid("9bf7c640-b620-456f-a550-0348f366544b"));
 
         boolean result = dao.updateConsoleUserWithOptimisticLocking(vmWithoutConsoleUser);
@@ -152,7 +123,7 @@ public class VmDynamicDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testUpdateConsoleUserWithOptimisticLockingFailure() throws Exception {
-        VmDynamic vmWithoutConsoleUser = dao.get(new Guid("77296e00-0cad-4e5a-9299-008a7b6f4355"));
+        VmDynamic vmWithoutConsoleUser = dao.get(FixturesTool.VM_RHEL5_POOL_57);
         vmWithoutConsoleUser.setConsoleUserId(new Guid("9bf7c640-b620-456f-a550-0348f366544b"));
 
         boolean result = dao.updateConsoleUserWithOptimisticLocking(vmWithoutConsoleUser);
@@ -162,21 +133,20 @@ public class VmDynamicDaoTest extends BaseDaoTestCase {
 
     @Test
     public void testClearMigratingToVds() throws Exception {
-        Guid vmId = new Guid("77296e00-0cad-4e5a-9299-008a7b6f4356");
-        VmDynamic vmDynamic = dao.get(vmId);
+        VmDynamic vmDynamic = dao.get(FixturesTool.VM_RHEL5_POOL_51);
         assertNotNull("migrating_to_vds field should not be null before we clear it",
                 vmDynamic.getMigratingToVds());
 
-        dao.clearMigratingToVds(vmId);
+        dao.clearMigratingToVds(FixturesTool.VM_RHEL5_POOL_51);
 
-        vmDynamic = dao.get(vmId);
+        vmDynamic = dao.get(FixturesTool.VM_RHEL5_POOL_51);
         assertNull("migrating_to_vds field should be null after we clear it",
                 vmDynamic.getMigratingToVds());
     }
 
     @Test
     public void testGuestAgentStatus() throws Exception {
-        Guid vmId = new Guid("77296e00-0cad-4e5a-9299-008a7b6f4356");
+        Guid vmId = FixturesTool.VM_RHEL5_POOL_51;
         VmDynamic vmDynamic = dao.get(vmId);
         vmDynamic.setGuestAgentStatus(GuestAgentStatus.UpdateNeeded);
         dao.update(vmDynamic);
@@ -186,10 +156,10 @@ public class VmDynamicDaoTest extends BaseDaoTestCase {
 
     @Test
     public void testUpdateToUnknown() {
-        VmDynamic existingVm2 = dao.get(new Guid("77296e00-0cad-4e5a-9299-008a7b6f4356"));
-        VmDynamic existingVm3 = dao.get(new Guid("77296e00-0cad-4e5a-9299-008a7b6f4354"));
-        dao.updateVmsToUnknown(Arrays.asList(existingVm.getId(), existingVm2.getId()));
-        assertEquals(VMStatus.Unknown, dao.get(existingVm.getId()).getStatus());
+        VmDynamic existingVm2 = dao.get(FixturesTool.VM_RHEL5_POOL_51);
+        VmDynamic existingVm3 = dao.get(FixturesTool.VM_RHEL5_POOL_50);
+        dao.updateVmsToUnknown(Arrays.asList(existingEntity.getId(), existingVm2.getId()));
+        assertEquals(VMStatus.Unknown, dao.get(existingEntity.getId()).getStatus());
         assertEquals(VMStatus.Unknown, dao.get(existingVm2.getId()).getStatus());
         assertNotEquals(VMStatus.Unknown, dao.get(existingVm3.getId()).getStatus());
     }
