@@ -14,7 +14,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.stream.Collectors;
 
-import org.apache.commons.collections.CollectionUtils;
 import org.hamcrest.Matchers;
 import org.junit.Test;
 import org.ovirt.engine.core.common.businessentities.ArchitectureType;
@@ -25,68 +24,58 @@ import org.ovirt.engine.core.common.businessentities.VmTemplate;
 import org.ovirt.engine.core.common.businessentities.VmTemplateStatus;
 import org.ovirt.engine.core.compat.Guid;
 
-public class VmTemplateDaoTest extends BaseDaoTestCase {
+public class VmTemplateDaoTest extends BaseGenericDaoTestCase<Guid, VmTemplate, VmTemplateDao> {
     private static final int NUMBER_OF_TEMPLATES_FOR_PRIVELEGED_USER = 1;
     private static final int NUMBER_OF_INSTANCE_TYPES_FOR_PRIVELEGED_USER = 1;
     private static final int NUMBER_OF_TEMPLATES_IN_DB = 8;
-    private static final Guid EXISTING_TEMPLATE_ID = new Guid("1b85420c-b84c-4f29-997e-0eb674b40b79");
-    private static final Guid DELETABLE_TEMPLATE_ID = new Guid("1b85420c-b84c-4f29-997e-0eb674b40b80");
-    private static final Guid STORAGE_DOMAIN_ID = new Guid("72e3a666-89e1-4005-a7ca-f7548004a9ab");
-    private static final Guid CLUSTER_ID = new Guid("b399944a-81ab-4ec5-8266-e19ba7c3c9d1");
-    private static final Guid EXISTING_INSTANCE_TYPE_ID = new Guid("99408929-82cf-4dc7-a532-9d998063fa95");
     private static final Guid EXISTING_IMAGE_TYPE_ID = new Guid("5849b030-626e-47cb-ad90-3ce782d831b3");
-    private static final Guid SMALL_ICON_ID = new Guid("38fc5e1a-f96b-339b-9894-def6f366daf5");
-    private static final Guid LARGE_ICON_ID = new Guid("a3b954f0-31ff-3166-b7a1-28b23202b198");
-    protected static final Guid[] HOST_GUIDS = {new Guid("afce7a39-8e8c-4819-ba9c-796d316592e6"),
-        new Guid("afce7a39-8e8c-4819-ba9c-796d316592e7"),
-        new Guid("23f6d691-5dfb-472b-86dc-9e1d2d3c18f3")};
-
-    private VmTemplateDao dao;
-
-    private VmTemplate newVmTemplate;
-    private VmTemplate existingTemplate;
-    private VmTemplate existingInstanceType;
+    protected static final Guid[] HOST_GUIDS = {FixturesTool.VDS_RHEL6_NFS_SPM,
+            FixturesTool.HOST_ID,
+            FixturesTool.GLUSTER_BRICK_SERVER1};
 
     @Override
-    public void setUp() throws Exception {
-        super.setUp();
-
-        dao = dbFacade.getVmTemplateDao();
-
-        existingTemplate = dao.get(
-                new Guid("1b85420c-b84c-4f29-997e-0eb674b40b79"));
-
-        existingInstanceType = dao.get(
-                new Guid("99408929-82cf-4dc7-a532-9d998063fa95"));
-
-        newVmTemplate = new VmTemplate();
+    protected VmTemplate generateNewEntity() {
+        VmTemplate newVmTemplate = new VmTemplate();
         newVmTemplate.setId(Guid.newGuid());
         newVmTemplate.setName("NewVmTemplate");
-        newVmTemplate.setClusterId(CLUSTER_ID);
+        newVmTemplate.setClusterId(FixturesTool.CLUSTER);
         newVmTemplate.setClusterArch(ArchitectureType.x86_64);
         newVmTemplate.setCpuProfileId(FixturesTool.CPU_PROFILE_2);
-        newVmTemplate.setSmallIconId(SMALL_ICON_ID);
-        newVmTemplate.setLargeIconId(LARGE_ICON_ID);
+        newVmTemplate.setSmallIconId(FixturesTool.SMALL_ICON_ID);
+        newVmTemplate.setLargeIconId(FixturesTool.LARGE_ICON_ID);
+        return newVmTemplate;
+    }
+
+    @Override
+    protected void updateExistingEntity() {
+        existingEntity.setDescription("This is an updated description");
+
+        List<Guid> hostGuidsList = Collections.singletonList(HOST_GUIDS[0]);
+        existingEntity.setDedicatedVmForVdsList(hostGuidsList);
+    }
+
+    @Override
+    protected Guid getExistingEntityId() {
+        return FixturesTool.VM_TEMPLATE_RHEL5;
+    }
+
+    @Override
+    protected VmTemplateDao prepareDao() {
+        return dbFacade.getVmTemplateDao();
+    }
+
+    @Override
+    protected Guid generateNonExistingId() {
+        return Guid.newGuid();
     }
 
     /**
-     * Ensures an id is required.
+     * Note the {@link VmTemplateDao#getAll()} returns only <strong>templates</strong>, while
+     * {@link VmTemplateDao#getCount()} also includes image types and and instance types.
      */
-    @Test
-    public void testGetWithInvalidId() {
-        VmTemplate result = dao.get(Guid.newGuid());
-
-        assertNull(result);
-    }
-
-    /**
-     * Ensures that the right template is returned.
-     */
-    @Test
-    public void testGet() {
-        VmTemplate result = dao.get(EXISTING_TEMPLATE_ID);
-
-        assertGetResult(result);
+    @Override
+    protected int getEntitiesTotalCount() {
+        return 6;
     }
 
     /**
@@ -94,10 +83,10 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetInstanceType() {
-        InstanceType result = dao.getInstanceType(EXISTING_INSTANCE_TYPE_ID);
+        InstanceType result = dao.getInstanceType(FixturesTool.INSTANCE_TYPE);
 
         assertNotNull(result);
-        assertEquals(EXISTING_INSTANCE_TYPE_ID, result.getId());
+        assertEquals(FixturesTool.INSTANCE_TYPE, result.getId());
     }
 
     /**
@@ -111,23 +100,14 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
         assertEquals(EXISTING_IMAGE_TYPE_ID, result.getId());
     }
 
-    /**
-     * Ensures that all templates are returned.
-     */
-    @Test
-    public void testGetAll() {
-        List<VmTemplate> result = dao.getAll();
-
-        assertGetAllResult(result);
-    }
-
     @Test
     public void testGetVmTemplatesByIds() {
-        List<VmTemplate> result = dao.getVmTemplatesByIds(Arrays.asList(EXISTING_TEMPLATE_ID, DELETABLE_TEMPLATE_ID));
+        List<VmTemplate> result = dao.getVmTemplatesByIds(Arrays.asList(FixturesTool.VM_TEMPLATE_RHEL5,
+                FixturesTool.VM_TEMPLATE_RHEL5_2));
         assertEquals("loaded templates list isn't in the expected size", 2, result.size());
         Collection<Guid> recieved = result.stream().map(VmTemplate::getId).collect(Collectors.toList());
-        assertTrue("the received list didn't contain an expected Template", recieved.contains(EXISTING_TEMPLATE_ID));
-        assertTrue("the received list didn't contain an expected Template", recieved.contains(DELETABLE_TEMPLATE_ID));
+        assertTrue("the received list didn't contain an expected Template", recieved.contains(FixturesTool.VM_TEMPLATE_RHEL5));
+        assertTrue("the received list didn't contain an expected Template", recieved.contains(FixturesTool.VM_TEMPLATE_RHEL5_2));
     }
 
     /**
@@ -139,7 +119,7 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
 
         assertNotNull(result);
         assertEquals(NUMBER_OF_TEMPLATES_FOR_PRIVELEGED_USER, result.size());
-        assertEquals(result.iterator().next(), existingTemplate);
+        assertEquals(result.iterator().next(), existingEntity);
     }
 
     /**
@@ -166,6 +146,7 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetAllInstanceTypesWithPermissionsForPriviligedUser() {
+        VmTemplate existingInstanceType = dao.get(FixturesTool.INSTANCE_TYPE);
         List<VmTemplate> result = dao.getAll(PRIVILEGED_USER_ID, true, VmEntityType.INSTANCE_TYPE);
 
         assertNotNull(result);
@@ -197,7 +178,7 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetAllForStorageDomain() {
-        List<VmTemplate> result = dao.getAllForStorageDomain(STORAGE_DOMAIN_ID);
+        List<VmTemplate> result = dao.getAllForStorageDomain(FixturesTool.STORAGE_DOMAIN_SCALE_SD5);
 
         assertGetAllResult(result);
     }
@@ -207,7 +188,7 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetAllForStorageDomainWithPermissionsForPriviligedUser() {
-        List<VmTemplate> result = dao.getAllForStorageDomain(STORAGE_DOMAIN_ID, PRIVILEGED_USER_ID, true);
+        List<VmTemplate> result = dao.getAllForStorageDomain(FixturesTool.STORAGE_DOMAIN_SCALE_SD5, PRIVILEGED_USER_ID, true);
         assertGetAllResult(result);
     }
 
@@ -216,7 +197,7 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetAllForStorageDomainWithPermissionsForUnpriviligedUser() {
-        List<VmTemplate> result = dao.getAllForStorageDomain(STORAGE_DOMAIN_ID, UNPRIVILEGED_USER_ID, true);
+        List<VmTemplate> result = dao.getAllForStorageDomain(FixturesTool.STORAGE_DOMAIN_SCALE_SD5, UNPRIVILEGED_USER_ID, true);
         assertNotNull(result);
         assertTrue(result.isEmpty());
     }
@@ -226,7 +207,7 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetAllForStorageDomainWithPermissionsDisabledForUnpriviligedUser() {
-        List<VmTemplate> result = dao.getAllForStorageDomain(STORAGE_DOMAIN_ID, UNPRIVILEGED_USER_ID, false);
+        List<VmTemplate> result = dao.getAllForStorageDomain(FixturesTool.STORAGE_DOMAIN_SCALE_SD5, UNPRIVILEGED_USER_ID, false);
         assertGetAllResult(result);
     }
 
@@ -245,11 +226,11 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetAllForCluster() {
-        List<VmTemplate> result = dao.getAllForCluster(CLUSTER_ID);
+        List<VmTemplate> result = dao.getAllForCluster(FixturesTool.CLUSTER);
 
         assertGetAllResult(result);
         for (VmTemplate template : result) {
-            assertEquals(CLUSTER_ID, template.getClusterId());
+            assertEquals(FixturesTool.CLUSTER, template.getClusterId());
         }
     }
 
@@ -263,52 +244,17 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
         assertNotNull(result.values());
     }
 
-    /**
-     * Ensures that saving a template works as expected.
-     */
-    @Test
-    public void testSave() {
-        newVmTemplate.setDedicatedVmForVdsList(Arrays.asList(HOST_GUIDS));
-        dao.save(newVmTemplate);
-
-        VmTemplate result = dbFacade.getVmTemplateDao().get(newVmTemplate.getId());
-
-        assertNotNull(result);
-        assertTrue(CollectionUtils.isEqualCollection(result.getDedicatedVmForVdsList(),
-                newVmTemplate.getDedicatedVmForVdsList()));
-        assertEquals(newVmTemplate, result);
-    }
-
-    /**
-     * Ensures that updating a template works as expected.
-     */
-    @Test
-    public void testUpdate() {
-        existingTemplate.setDescription("This is an updated description");
-
-        List<Guid> hostGuidsList = Collections.singletonList(HOST_GUIDS[0]);
-        existingTemplate.setDedicatedVmForVdsList(hostGuidsList);
-        dao.update(existingTemplate);
-
-        VmTemplate result = dbFacade.getVmTemplateDao().get(existingTemplate.getId());
-
-        assertNotNull(result);
-        assertTrue(CollectionUtils.isEqualCollection(result.getDedicatedVmForVdsList(),
-                existingTemplate.getDedicatedVmForVdsList()));
-        assertEquals(existingTemplate, result);
-    }
-
     /**
      * Ensures updating the status aspect of the VM Template works.
      */
     @Test
     public void testUpdateStatus() {
-        VmTemplate before = dao.get(existingTemplate.getId());
+        VmTemplate before = dao.get(existingEntity.getId());
 
         before.setStatus(VmTemplateStatus.Locked);
-        dao.updateStatus(existingTemplate.getId(), VmTemplateStatus.Locked);
+        dao.updateStatus(existingEntity.getId(), VmTemplateStatus.Locked);
 
-        VmTemplate after = dao.get(existingTemplate.getId());
+        VmTemplate after = dao.get(existingEntity.getId());
 
         assertEquals(before, after);
     }
@@ -318,13 +264,13 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testRemove() {
-        VmTemplate before = dbFacade.getVmTemplateDao().get(DELETABLE_TEMPLATE_ID);
+        VmTemplate before = dao.get(FixturesTool.VM_TEMPLATE_RHEL5_2);
 
         assertNotNull(before);
 
-        dao.remove(DELETABLE_TEMPLATE_ID);
+        dao.remove(FixturesTool.VM_TEMPLATE_RHEL5_2);
 
-        VmTemplate after = dbFacade.getVmTemplateDao().get(DELETABLE_TEMPLATE_ID);
+        VmTemplate after = dao.get(FixturesTool.VM_TEMPLATE_RHEL5_2);
 
         assertNull(after);
     }
@@ -334,7 +280,7 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
     */
     @Test
     public void testGetWithPermissionsForPriviligedUser() {
-        VmTemplate result = dao.get(EXISTING_TEMPLATE_ID, PRIVILEGED_USER_ID, true);
+        VmTemplate result = dao.get(FixturesTool.VM_TEMPLATE_RHEL5, PRIVILEGED_USER_ID, true);
         assertGetResult(result);
     }
 
@@ -343,7 +289,7 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
     */
     @Test
     public void testGetWithPermissionsForUnpriviligedUser() {
-        VmTemplate result = dao.get(EXISTING_TEMPLATE_ID, UNPRIVILEGED_USER_ID, true);
+        VmTemplate result = dao.get(FixturesTool.VM_TEMPLATE_RHEL5, UNPRIVILEGED_USER_ID, true);
         assertNull(result);
     }
 
@@ -352,7 +298,7 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
     */
     @Test
     public void testGetWithPermissionsDisabledForUnpriviligedUser() {
-        VmTemplate result = dao.get(EXISTING_TEMPLATE_ID, UNPRIVILEGED_USER_ID, false);
+        VmTemplate result = dao.get(FixturesTool.VM_TEMPLATE_RHEL5, UNPRIVILEGED_USER_ID, false);
         assertGetResult(result);
     }
 
@@ -362,7 +308,7 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
     @Test
     public void testGetAllForNetwork() {
         List<VmTemplate> result = dao.getAllForNetwork(FixturesTool.NETWORK_ENGINE);
-        assertEquals(existingTemplate, result.get(0));
+        assertEquals(existingEntity, result.get(0));
     }
 
     /**
@@ -371,7 +317,7 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
     @Test
     public void testGetAllVnicProfile() {
         List<VmTemplate> result = dao.getAllForVnicProfile(FixturesTool.VM_NETWORK_INTERFACE_PROFILE);
-        assertEquals(existingTemplate, result.get(0));
+        assertEquals(existingEntity, result.get(0));
     }
 
     /**
@@ -386,7 +332,7 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
 
     private static void assertGetResult(VmTemplate result) {
         assertNotNull(result);
-        assertEquals(EXISTING_TEMPLATE_ID, result.getId());
+        assertEquals(FixturesTool.VM_TEMPLATE_RHEL5, result.getId());
         assertEquals("Template generation wasn't loaded as expected", 1, result.getDbGeneration());
     }
 
@@ -458,8 +404,8 @@ public class VmTemplateDaoTest extends BaseDaoTestCase {
 
     @Test
     public void testGetAllWithLeaseOnStorageDomain() {
-        List<Guid> vmAndTemplatesWithLeasesIds = dao.getAllWithLeaseOnStorageDomain(FixturesTool.STORAGE_DOAMIN_NFS2_1)
-                .stream().map(t -> t.getId()).collect(Collectors.toList());
+        List<Guid> vmAndTemplatesWithLeasesIds = dao.getAllWithLeaseOnStorageDomain(FixturesTool.STORAGE_DOMAIN_NFS2_1)
+                .stream().map(VmTemplate::getId).collect(Collectors.toList());
         assertThat(vmAndTemplatesWithLeasesIds,
                 Matchers.contains(FixturesTool.VM_TEMPLATE_RHEL5_2));
     }
