@@ -11,6 +11,8 @@ import java.util.List;
 import java.util.Set;
 
 import org.junit.Test;
+import org.ovirt.engine.core.common.businessentities.network.DnsResolverConfiguration;
+import org.ovirt.engine.core.common.businessentities.network.NameServer;
 import org.ovirt.engine.core.common.businessentities.network.Network;
 import org.ovirt.engine.core.common.businessentities.network.NetworkCluster;
 import org.ovirt.engine.core.compat.Guid;
@@ -21,9 +23,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
     private static final Guid MANAGEMENT_NETWORK_ID = new Guid("58d5c1c6-cb15-4832-b2a4-1234567890ab");
 
     private NetworkDao dao;
-    private Guid cluster;
-    private Guid datacenter;
-    private Network new_net;
+    private Network newNet;
     private static final String EXISTING_NETWORK_NAME1 = "engine";
     private static final String EXISTING_NETWORK_NAME2 = "engine3";
     private static final int NUM_OF_NETWORKS = 7;
@@ -36,14 +36,11 @@ public class NetworkDaoTest extends BaseDaoTestCase {
 
         dao = dbFacade.getNetworkDao();
 
-        cluster = new Guid("b399944a-81ab-4ec5-8266-e19ba7c3c9d1");
-        datacenter = new Guid("6d849ebf-755f-4552-ad09-9a090cda105d");
-
-        new_net = new Network();
-        new_net.setName("newnet1");
-        new_net.setVdsmName("newnet1");
-        new_net.setDescription("New network");
-        new_net.setDataCenterId(datacenter);
+        newNet = new Network();
+        newNet.setName("newnet1");
+        newNet.setVdsmName("newnet1");
+        newNet.setDescription("New network");
+        newNet.setDataCenterId(FixturesTool.DATA_CENTER);
     }
 
     /**
@@ -51,7 +48,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetByNameWithInvalidName() {
-        Network result = dao.getByName("farkle");
+        Network result = dao.getByNameAndCluster("farkle", FixturesTool.CLUSTER);
 
         assertNull(result);
     }
@@ -61,7 +58,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetByName() {
-        Network result = dao.getByName(EXISTING_NETWORK_NAME1);
+        Network result = dao.getByNameAndCluster(EXISTING_NETWORK_NAME1, FixturesTool.CLUSTER);
 
         assertNotNull(result);
         assertEquals(EXISTING_NETWORK_NAME1, result.getName());
@@ -72,7 +69,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetByNameAndDataCenter() {
-        Network result = dao.getByNameAndDataCenter(EXISTING_NETWORK_NAME1, datacenter);
+        Network result = dao.getByNameAndDataCenter(EXISTING_NETWORK_NAME1, FixturesTool.DATA_CENTER);
 
         assertNotNull(result);
         assertEquals(EXISTING_NETWORK_NAME1, result.getName());
@@ -83,7 +80,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetByNameAndCluster() {
-        Network result = dao.getByNameAndCluster(EXISTING_NETWORK_NAME1, cluster);
+        Network result = dao.getByNameAndCluster(EXISTING_NETWORK_NAME1, FixturesTool.CLUSTER);
 
         assertNotNull(result);
         assertEquals(EXISTING_NETWORK_NAME1, result.getName());
@@ -94,7 +91,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetManagementNetworkByCluster() {
-        Network result = dao.getManagementNetwork(cluster);
+        Network result = dao.getManagementNetwork(FixturesTool.CLUSTER);
 
         assertNotNull(result);
         assertEquals(MANAGEMENT_NETWORK_ID, result.getId());
@@ -105,7 +102,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetManagementNetworks() {
-        List<Network> result = dao.getManagementNetworks(datacenter);
+        List<Network> result = dao.getManagementNetworks(FixturesTool.DATA_CENTER);
 
         assertEquals(NUM_OF_MANAGEMENT_NETWORKS, result.size());
     }
@@ -169,7 +166,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetAllForCluster() {
-        List<Network> result = dao.getAllForCluster(cluster);
+        List<Network> result = dao.getAllForCluster(FixturesTool.CLUSTER);
 
         assertGetAllForClusterResult(result);
     }
@@ -181,7 +178,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
     @Test
     public void testGetAllForClusterFilteredWithPermissions() {
         // A use with permissions
-        List<Network> result = dao.getAllForCluster(cluster, PRIVILEGED_USER_ID, true);
+        List<Network> result = dao.getAllForCluster(FixturesTool.CLUSTER, PRIVILEGED_USER_ID, true);
 
         assertGetAllForClusterResult(result);
     }
@@ -193,7 +190,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
     @Test
     public void testGetAllForClusterFilteredWithPermissionsNoPermissions() {
         // A use with permissions
-        List<Network> result = dao.getAllForCluster(cluster, UNPRIVILEGED_USER_ID, true);
+        List<Network> result = dao.getAllForCluster(FixturesTool.CLUSTER, UNPRIVILEGED_USER_ID, true);
 
         assertNotNull(result);
         assertTrue(result.isEmpty());
@@ -206,7 +203,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
     @Test
     public void testGetAllForClusterFilteredWithPermissionsNoPermissionsAndNoFilter() {
         // A use with permissions
-        List<Network> result = dao.getAllForCluster(cluster, UNPRIVILEGED_USER_ID, false);
+        List<Network> result = dao.getAllForCluster(FixturesTool.CLUSTER, UNPRIVILEGED_USER_ID, false);
 
         assertGetAllForClusterResult(result);
     }
@@ -248,7 +245,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetAllForDataCenter() {
-        List<Network> result = dao.getAllForDataCenter(datacenter);
+        List<Network> result = dao.getAllForDataCenter(FixturesTool.DATA_CENTER);
         verifyDataCenterNetworks(result);
     }
 
@@ -258,7 +255,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testFilteredGetAllForDataCenter() {
-        List<Network> result = dao.getAllForDataCenter(datacenter, PRIVILEGED_USER_ID, true);
+        List<Network> result = dao.getAllForDataCenter(FixturesTool.DATA_CENTER, PRIVILEGED_USER_ID, true);
         verifyDataCenterNetworks(result);
     }
 
@@ -268,7 +265,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testFilteredGetAllForDataCenterWithNoPermissions() {
-        List<Network> result = dao.getAllForDataCenter(datacenter, UNPRIVILEGED_USER_ID, true);
+        List<Network> result = dao.getAllForDataCenter(FixturesTool.DATA_CENTER, UNPRIVILEGED_USER_ID, true);
         assertNotNull(result);
         assertTrue(result.isEmpty());
     }
@@ -278,7 +275,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testUnFilteredGetAllForDataCenterWithNoPermissions() {
-        List<Network> result = dao.getAllForDataCenter(datacenter, PRIVILEGED_USER_ID, false);
+        List<Network> result = dao.getAllForDataCenter(FixturesTool.DATA_CENTER, PRIVILEGED_USER_ID, false);
         verifyDataCenterNetworks(result);
     }
 
@@ -286,7 +283,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
         assertNotNull(result);
         assertFalse(result.isEmpty());
         for (Network net : result) {
-            assertEquals(datacenter, net.getDataCenterId());
+            assertEquals(FixturesTool.DATA_CENTER, net.getDataCenterId());
         }
     }
 
@@ -330,7 +327,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testGetAllNetworkLabelsForDataCenter() {
-        Set<String> result = dao.getAllNetworkLabelsForDataCenter(datacenter);
+        Set<String> result = dao.getAllNetworkLabelsForDataCenter(FixturesTool.DATA_CENTER);
         assertNotNull(result);
         assertFalse(result.isEmpty());
     }
@@ -340,7 +337,7 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void getAllByLabelForCluster() {
-        List<Network> result = dao.getAllByLabelForCluster(NETWORK_LABEL, cluster);
+        List<Network> result = dao.getAllByLabelForCluster(NETWORK_LABEL, FixturesTool.CLUSTER);
         assertNotNull(result);
         assertFalse(result.isEmpty());
 
@@ -354,17 +351,19 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testSave() {
-        List<NetworkCluster> clustersFromDB = dbFacade.getNetworkClusterDao().getAllForCluster(cluster);
+        List<NetworkCluster> clustersFromDB = dbFacade.getNetworkClusterDao().getAllForCluster(FixturesTool.CLUSTER);
+        DnsResolverConfiguration dnsResolverConfiguration =
+                dbFacade.getDnsResolverConfigurationDao().get(FixturesTool.EXISTING_DNS_RESOLVER_CONFIGURATION);
+
         NetworkCluster clusterFromDB = clustersFromDB.get(0);
         assertNotNull(clusterFromDB);
-        new_net.setCluster(clusterFromDB);
-        new_net.setId(Guid.newGuid());
-        dao.save(new_net);
-
-        Network result = dao.getByName(new_net.getName());
-
+        newNet.setCluster(clusterFromDB);
+        newNet.setId(Guid.newGuid());
+        newNet.setDnsResolverConfiguration(dnsResolverConfiguration);
+        dao.save(newNet);
+        Network result = dao.getByNameAndDataCenter(newNet.getName(), FixturesTool.DATA_CENTER);
         assertNotNull(result);
-        assertEquals(new_net, result);
+        assertEquals(newNet, result);
     }
 
     /**
@@ -372,13 +371,14 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testUpdate() {
-        Network before = dao.getByName(EXISTING_NETWORK_NAME1);
+        Network before = dao.getByNameAndCluster(EXISTING_NETWORK_NAME1, FixturesTool.CLUSTER);
 
         before.setDescription("This is a completely changed description");
+        before.getDnsResolverConfiguration().getNameServers().add(new NameServer("1.1.1.1"));
 
         dao.update(before);
 
-        Network after = dao.getByName(EXISTING_NETWORK_NAME1);
+        Network after = dao.getByNameAndCluster(EXISTING_NETWORK_NAME1, FixturesTool.CLUSTER);
 
         assertNotNull(after);
         assertEquals(before, after);
@@ -389,14 +389,16 @@ public class NetworkDaoTest extends BaseDaoTestCase {
      */
     @Test
     public void testRemove() {
-        Network result = dao.getByName(EXISTING_NETWORK_NAME2);
+        DnsResolverConfigurationDao dnsResolverConfigurationDao = dbFacade.getDnsResolverConfigurationDao();
+
+        Network result = dao.getByNameAndDataCenter(EXISTING_NETWORK_NAME2, FixturesTool.DATA_CENTER);
 
         assertNotNull(result);
+        assertEquals(result.getDnsResolverConfiguration().getId(), FixturesTool.EXISTING_DNS_RESOLVER_CONFIGURATION_TO_REMOVE);
 
         dao.remove(result.getId());
 
-        result = dao.getByName(EXISTING_NETWORK_NAME2);
-
-        assertNull(result);
+        assertNull(dao.getByNameAndDataCenter(EXISTING_NETWORK_NAME2, FixturesTool.DATA_CENTER));
+        assertNull(dnsResolverConfigurationDao.get(FixturesTool.EXISTING_DNS_RESOLVER_CONFIGURATION_TO_REMOVE));
     }
 }
