@@ -1,12 +1,12 @@
 package org.ovirt.engine.api.restapi.resource;
 
 import java.util.List;
+
 import javax.ws.rs.core.Response;
 
 import org.ovirt.engine.api.model.BaseResource;
 import org.ovirt.engine.api.model.Disk;
 import org.ovirt.engine.api.model.Disks;
-import org.ovirt.engine.api.model.StorageDomain;
 import org.ovirt.engine.api.model.StorageType;
 import org.ovirt.engine.api.resource.DiskResource;
 import org.ovirt.engine.api.resource.DisksResource;
@@ -14,12 +14,12 @@ import org.ovirt.engine.api.restapi.logging.Messages;
 import org.ovirt.engine.api.restapi.resource.utils.DiskResourceUtils;
 import org.ovirt.engine.api.restapi.types.DiskMapper;
 import org.ovirt.engine.api.restapi.util.LinkHelper;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.AddDiskParameters;
-import org.ovirt.engine.core.common.action.VdcActionType;
 import org.ovirt.engine.core.common.interfaces.SearchType;
 import org.ovirt.engine.core.common.queries.IdQueryParameters;
-import org.ovirt.engine.core.common.queries.VdcQueryParametersBase;
-import org.ovirt.engine.core.common.queries.VdcQueryType;
+import org.ovirt.engine.core.common.queries.QueryParametersBase;
+import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.core.compat.Guid;
 
 public class BackendDisksResource
@@ -43,8 +43,14 @@ public class BackendDisksResource
         if (disk.isSetLunStorage() && disk.getLunStorage().isSetHost()) {
             params.setVdsId(getHostId(disk.getLunStorage().getHost()));
         }
-        return performCreate(VdcActionType.AddDisk, params,
-                new QueryIdResolver<Guid>(VdcQueryType.GetDiskByDiskId, IdQueryParameters.class));
+        if (disk.isSetId()) {
+            params.setUsePassedDiskId(true);
+        }
+        if (disk.isSetImageId()) {
+            params.setUsePassedImageId(true);
+        }
+        return performCreate(ActionType.AddDisk, params,
+                new QueryIdResolver<Guid>(QueryType.GetDiskByDiskId, IdQueryParameters.class));
     }
 
     private void updateStorageTypeForDisk(Disk disk, Guid storageDomainId) {
@@ -59,9 +65,10 @@ public class BackendDisksResource
                 && disk.getStorageDomains().getStorageDomains().get(0).isSetId()) {
             return asGuid(disk.getStorageDomains().getStorageDomains().get(0).getId());
         } else if (disk.isSetStorageDomains() && disk.getStorageDomains().getStorageDomains().get(0).isSetName()) {
-            Guid storageDomainId = getStorageDomainIdByName(disk.getStorageDomains().getStorageDomains().get(0).getName());
+            String storageName = disk.getStorageDomains().getStorageDomains().get(0).getName();
+            Guid storageDomainId = getStorageDomainIdByName(storageName);
             if (storageDomainId == null) {
-                notFound(StorageDomain.class);
+                notFound(storageName);
             } else {
                 return storageDomainId;
             }
@@ -70,7 +77,7 @@ public class BackendDisksResource
     }
 
     private org.ovirt.engine.core.common.businessentities.StorageDomain getStorageDomainById(Guid id) {
-        return getEntity(org.ovirt.engine.core.common.businessentities.StorageDomain.class, VdcQueryType.GetStorageDomainById, new IdQueryParameters(id), id.toString());
+        return getEntity(org.ovirt.engine.core.common.businessentities.StorageDomain.class, QueryType.GetStorageDomainById, new IdQueryParameters(id), id.toString());
     }
 
     protected void validateDiskForCreation(Disk disk) {
@@ -95,8 +102,8 @@ public class BackendDisksResource
     private Guid getStorageDomainIdByName(String storageDomainName) {
         List<org.ovirt.engine.core.common.businessentities.StorageDomain> storageDomains =
                 getBackendCollection(org.ovirt.engine.core.common.businessentities.StorageDomain.class,
-                        VdcQueryType.GetAllStorageDomains,
-                        new VdcQueryParametersBase());
+                        QueryType.GetAllStorageDomains,
+                        new QueryParametersBase());
         for (org.ovirt.engine.core.common.businessentities.StorageDomain storageDomain : storageDomains) {
             if (storageDomain.getStorageName().equals(storageDomainName)) {
                 return storageDomain.getId();
@@ -108,9 +115,11 @@ public class BackendDisksResource
     @Override
     public Disks list() {
         if (isFiltered()) {
-            return mapCollection(getBackendCollection(VdcQueryType.GetAllDisks, new VdcQueryParametersBase()));
+            return mapCollection(getBackendCollection(QueryType.GetAllDisksWithSnapshots, new QueryParametersBase()));
         } else {
-            return mapCollection(getBackendCollection(SearchType.Disk));
+            return mapCollection(getBackendCollection(QueryType.GetAllDisksWithSnapshots,
+                    new QueryParametersBase(),
+                    SearchType.Disk));
         }
     }
 
