@@ -4,18 +4,18 @@ import java.util.List;
 
 import org.ovirt.engine.api.model.User;
 import org.ovirt.engine.api.resource.AssignedTagResource;
-import org.ovirt.engine.core.common.action.VdcActionType;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.businessentities.Tags;
 import org.ovirt.engine.core.common.queries.GetTagsByUserIdParameters;
-import org.ovirt.engine.core.common.queries.VdcQueryType;
+import org.ovirt.engine.core.common.queries.QueryType;
 
 public class BackendUserTagsResource extends AbstractBackendAssignedTagsResource {
     public BackendUserTagsResource(String parentId) {
-        super(User.class, parentId, VdcActionType.AttachUserToTag);
+        super(User.class, parentId, ActionType.AttachUserToTag);
     }
 
     public List<Tags> getCollection() {
-        return getBackendCollection(VdcQueryType.GetTagsByUserId, new GetTagsByUserIdParameters(parentId));
+        return getBackendCollection(QueryType.GetTagsByUserId, new GetTagsByUserIdParameters(parentId));
     }
 
     @Override
