@@ -4,6 +4,7 @@ import java.nio.charset.StandardCharsets;
 import java.text.MessageFormat;
 import java.util.Collection;
 import java.util.List;
+
 import javax.ws.rs.core.Response;
 import javax.ws.rs.core.Response.Status;
 
@@ -19,14 +20,14 @@ import org.ovirt.engine.api.restapi.util.QueryHelper;
 import org.ovirt.engine.api.restapi.utils.DirectoryEntryIdUtils;
 import org.ovirt.engine.api.restapi.utils.aaa.AuthzUtils;
 import org.ovirt.engine.core.aaa.DirectoryGroup;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.AddGroupParameters;
-import org.ovirt.engine.core.common.action.VdcActionType;
 import org.ovirt.engine.core.common.businessentities.aaa.DbGroup;
 import org.ovirt.engine.core.common.interfaces.SearchType;
 import org.ovirt.engine.core.common.queries.DirectoryIdQueryParameters;
 import org.ovirt.engine.core.common.queries.IdQueryParameters;
-import org.ovirt.engine.core.common.queries.VdcQueryParametersBase;
-import org.ovirt.engine.core.common.queries.VdcQueryType;
+import org.ovirt.engine.core.common.queries.QueryParametersBase;
+import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.core.compat.Guid;
 
 /**
@@ -72,7 +73,7 @@ public class BackendGroupsResource
         }
         else if (group.isSetDomain() && group.getDomain().isSetId()) {
             for (String domain : authzProvidersNames) {
-                Guid domainId = new Guid(domain.getBytes(StandardCharsets.UTF_8), true);
+                Guid domainId = new Guid(domain.getBytes(StandardCharsets.UTF_8));
                 if (domainId.toString().equals(group.getDomain().getId())) {
                    return domain;
                 }
@@ -127,7 +128,7 @@ public class BackendGroupsResource
     @Override
     public Groups list() {
         if (isFiltered()) {
-            return mapDbGroupCollection(getBackendCollection(VdcQueryType.GetAllDbGroups, new VdcQueryParametersBase(), SearchType.DBGroup));
+            return mapDbGroupCollection(getBackendCollection(QueryType.GetAllDbGroups, new QueryParametersBase(), SearchType.DBGroup));
         }
         else {
             return mapDbGroupCollection(getBackendCollection(SearchType.DBGroup, getSearchPattern()));
@@ -138,8 +139,8 @@ public class BackendGroupsResource
     public Response add(Group group) {
         List<String> authzProvidersNames = getBackendCollection(
                 String.class,
-                VdcQueryType.GetDomainList,
-                new VdcQueryParametersBase());
+                QueryType.GetDomainList,
+                new QueryParametersBase());
         validateParameters(group, "name");
         if (AuthzUtils.getAuthzNameFromEntityName(group.getName(), authzProvidersNames) == null) {
             validateParameters(group, "domain.id|name");
@@ -153,8 +154,8 @@ public class BackendGroupsResource
         }
         AddGroupParameters parameters = new AddGroupParameters();
         parameters.setGroupToAdd(new DbGroup(directoryGroup));
-        QueryIdResolver<Guid> resolver = new QueryIdResolver<>(VdcQueryType.GetDbGroupById, IdQueryParameters.class);
-        return performCreate(VdcActionType.AddGroup, parameters, resolver, BaseResource.class);
+        QueryIdResolver<Guid> resolver = new QueryIdResolver<>(QueryType.GetDbGroupById, IdQueryParameters.class);
+        return performCreate(ActionType.AddGroup, parameters, resolver, BaseResource.class);
     }
 
     /**
@@ -191,7 +192,7 @@ public class BackendGroupsResource
         }
         return getEntity(
                 DirectoryGroup.class,
-                VdcQueryType.GetDirectoryGroupById,
+                QueryType.GetDirectoryGroupById,
                 new DirectoryIdQueryParameters(directoryName, namespace, groupId),
                 groupId,
                 true);
