@@ -20,13 +20,13 @@ import org.junit.Test;
 import org.ovirt.engine.api.model.Watchdog;
 import org.ovirt.engine.api.model.WatchdogAction;
 import org.ovirt.engine.api.model.WatchdogModel;
-import org.ovirt.engine.core.common.action.VdcActionType;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.WatchdogParameters;
 import org.ovirt.engine.core.common.businessentities.VmWatchdog;
 import org.ovirt.engine.core.common.businessentities.VmWatchdogAction;
 import org.ovirt.engine.core.common.businessentities.VmWatchdogType;
 import org.ovirt.engine.core.common.queries.IdQueryParameters;
-import org.ovirt.engine.core.common.queries.VdcQueryType;
+import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.core.compat.Guid;
 
 public class BackendTemplateWatchdogResourceTest
@@ -52,7 +52,7 @@ public class BackendTemplateWatchdogResourceTest
         setUpEntityQueryExpectations(2);
         setUriInfo(
             setUpActionExpectations(
-                VdcActionType.UpdateWatchdog,
+                ActionType.UpdateWatchdog,
                 WatchdogParameters.class,
                 new String[] { "Id" },
                 new Object[] { TEMPLATE_ID },
@@ -69,7 +69,7 @@ public class BackendTemplateWatchdogResourceTest
         setUpEntityQueryExpectations(1);
         setUriInfo(
             setUpActionExpectations(
-                VdcActionType.RemoveWatchdog,
+                ActionType.RemoveWatchdog,
                 WatchdogParameters.class,
                 new String[] { "Id" },
                 new Object[] { TEMPLATE_ID },
@@ -83,7 +83,7 @@ public class BackendTemplateWatchdogResourceTest
     private void setUpEntityQueryExpectations(int cnt) throws Exception {
         for (int i = 0; i < cnt; i++) {
             setUpGetEntityExpectations(
-                VdcQueryType.GetWatchdog,
+                QueryType.GetWatchdog,
                 IdQueryParameters.class,
                 new String[] { "Id" },
                 new Object[] { TEMPLATE_ID },
