@@ -42,10 +42,13 @@ class Plugin(plugin.PluginBase):
 
     def __init__(self, context):
         super(Plugin, self).__init__(context=context)
+        self.environment.setdefault(
+            osetupcons.CoreEnv.SETUP_ATTRS_MODULES,
+            []
+        )
 
     @plugin.event(
         stage=plugin.Stages.STAGE_BOOT,
-        priority=plugin.Stages.PRIORITY_HIGH - 20,
     )
     def _preinit(self):
         self.environment.setdefault(
@@ -61,6 +64,19 @@ class Plugin(plugin.PluginBase):
         )
         logging.getLogger('ovirt').setLevel(logging.DEBUG)
 
+    @plugin.event(
+        stage=plugin.Stages.STAGE_BOOT,
+        before=(
+            osetupcons.Stages.SECRETS_FILTERED_FROM_SETUP_ATTRS_MODULES,
+        )
+    )
+    def _boot(self):
+        self.environment[
+            osetupcons.CoreEnv.SETUP_ATTRS_MODULES
+        ].extend((
+            osetupcons,
+        ))
+
     @plugin.event(
         stage=plugin.Stages.STAGE_INIT,
         priority=plugin.Stages.PRIORITY_HIGH,
@@ -88,7 +104,7 @@ class Plugin(plugin.PluginBase):
         )
         self.environment.setdefault(
             osetupcons.CoreEnv.UPGRADE_SUPPORTED_VERSIONS,
-            '3.6,4.0,4.1'
+            '3.6,4.0,4.1,4.2'
         )
 
         self.logger.debug(
@@ -98,10 +114,6 @@ class Plugin(plugin.PluginBase):
             osetupcons.Const.DISPLAY_VERSION,
         )
 
-        self.environment[
-            osetupcons.CoreEnv.SETUP_ATTRS_MODULES
-        ] = [osetupcons]
-
         if self.environment[osetupcons.CoreEnv.DEVELOPER_MODE] is None:
             self.environment[osetupcons.CoreEnv.DEVELOPER_MODE] = False
             if os.geteuid() != 0:
