@@ -6,26 +6,24 @@ import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 
-import org.ovirt.engine.core.common.action.VdcActionParametersBase;
-import org.ovirt.engine.core.common.action.VdcActionType;
-import org.ovirt.engine.core.common.action.VdcReturnValueBase;
+import org.ovirt.engine.core.common.action.ActionParametersBase;
+import org.ovirt.engine.core.common.action.ActionReturnValue;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.gluster.GlusterServiceParameters;
 import org.ovirt.engine.core.common.action.gluster.RemoveGlusterServerParameters;
 import org.ovirt.engine.core.common.action.hostdeploy.AddVdsActionParameters;
 import org.ovirt.engine.core.common.businessentities.Cluster;
 import org.ovirt.engine.core.common.businessentities.MigrateOnErrorOptions;
 import org.ovirt.engine.core.common.businessentities.VDS;
-import org.ovirt.engine.core.common.businessentities.gluster.GlusterClusterService;
 import org.ovirt.engine.core.common.businessentities.gluster.GlusterServerService;
 import org.ovirt.engine.core.common.businessentities.gluster.GlusterServiceStatus;
 import org.ovirt.engine.core.common.businessentities.gluster.GlusterStatus;
 import org.ovirt.engine.core.common.businessentities.gluster.GlusterVolumeEntity;
 import org.ovirt.engine.core.common.businessentities.gluster.ServiceType;
 import org.ovirt.engine.core.common.queries.IdQueryParameters;
-import org.ovirt.engine.core.common.queries.VdcQueryReturnValue;
-import org.ovirt.engine.core.common.queries.VdcQueryType;
+import org.ovirt.engine.core.common.queries.QueryReturnValue;
+import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.core.compat.Guid;
-import org.ovirt.engine.ui.frontend.AsyncCallback;
 import org.ovirt.engine.ui.frontend.Frontend;
 import org.ovirt.engine.ui.uicommonweb.UICommand;
 import org.ovirt.engine.ui.uicommonweb.dataprovider.AsyncDataProvider;
@@ -35,10 +33,6 @@ import org.ovirt.engine.ui.uicommonweb.models.gluster.DetachGlusterHostsModel;
 import org.ovirt.engine.ui.uicommonweb.models.hosts.HostDetailModel;
 import org.ovirt.engine.ui.uicommonweb.models.hosts.MultipleHostsModel;
 import org.ovirt.engine.ui.uicompat.ConstantsManager;
-import org.ovirt.engine.ui.uicompat.FrontendActionAsyncResult;
-import org.ovirt.engine.ui.uicompat.FrontendMultipleActionAsyncResult;
-import org.ovirt.engine.ui.uicompat.IFrontendActionAsyncCallback;
-import org.ovirt.engine.ui.uicompat.IFrontendMultipleActionAsyncCallback;
 import org.ovirt.engine.ui.uicompat.PropertyChangedEventArgs;
 
 public class ClusterGeneralModel extends EntityModel<Cluster> {
@@ -218,29 +212,21 @@ public class ClusterGeneralModel extends EntityModel<Cluster> {
         setEmulatedMachine(cluster.getEmulatedMachine());
         setCompatibilityVersion(cluster.getCompatibilityVersion().getValue());
         generateClusterType(cluster.supportsGlusterService(), cluster.supportsVirtService());
-        AsyncDataProvider.getInstance().getNumberOfVmsInCluster(new AsyncQuery<>(new AsyncCallback<VdcQueryReturnValue>() {
-            @Override
-            public void onSuccess(VdcQueryReturnValue returnValue) {
-                setNumberOfVms((Integer) returnValue.getReturnValue());
-            }
-        }), cluster.getId());
+        AsyncDataProvider.getInstance().getNumberOfVmsInCluster(new AsyncQuery<>(
+                (QueryReturnValue returnValue) -> setNumberOfVms((Integer) returnValue.getReturnValue())), cluster.getId());
 
     }
 
     private void updateConsoleAddressPartiallyOverridden(Cluster cluster) {
 
-        AsyncQuery query = new AsyncQuery<>(
-                new AsyncCallback<VdcQueryReturnValue>() {
-                    @Override
-                    public void onSuccess(VdcQueryReturnValue returnValue) {
-                        boolean isConsistent = returnValue.getReturnValue();
-                        setConsoleAddressPartiallyOverridden(!isConsistent);
-                    }
-                }
-                );
+        AsyncQuery<QueryReturnValue> query = new AsyncQuery<>(returnValue -> {
+                boolean isConsistent = returnValue.getReturnValue();
+                setConsoleAddressPartiallyOverridden(!isConsistent);
+            }
+        );
 
         Frontend.getInstance().runQuery(
-                VdcQueryType.IsDisplayAddressConsistentInCluster,
+                QueryType.IsDisplayAddressConsistentInCluster,
                 new IdQueryParameters(cluster.getId()),
                 query
                 );
@@ -271,22 +257,19 @@ public class ClusterGeneralModel extends EntityModel<Cluster> {
                 || getGlusterSwiftStatus() == GlusterServiceStatus.MIXED
                 || getGlusterSwiftStatus() == GlusterServiceStatus.UNKNOWN);
 
-        AsyncDataProvider.getInstance().getGlusterSwiftServerServices(glusterSwiftModel.asyncQuery(new AsyncCallback<List<GlusterServerService>>() {
-            @Override
-            public void onSuccess(List<GlusterServerService> returnValue) {
-                List<GlusterSwiftServiceModel> serviceList = getGroupedGlusterSwiftServices(returnValue);
-                glusterSwiftModel.getHostServicesList().setItems(serviceList);
+        AsyncDataProvider.getInstance().getGlusterSwiftServerServices(glusterSwiftModel.asyncQuery(returnValue -> {
+            List<GlusterSwiftServiceModel> serviceList = getGroupedGlusterSwiftServices(returnValue);
+            glusterSwiftModel.getHostServicesList().setItems(serviceList);
 
-                glusterSwiftModel.stopProgress();
+            glusterSwiftModel.stopProgress();
 
-                UICommand command = UICommand.createDefaultOkUiCommand("OnManageGlusterSwift", ClusterGeneralModel.this); //$NON-NLS-1$
-                glusterSwiftModel.getCommands().add(command);
+            UICommand command = UICommand.createDefaultOkUiCommand("OnManageGlusterSwift", ClusterGeneralModel.this); //$NON-NLS-1$
+            glusterSwiftModel.getCommands().add(command);
 
-                command = new UICommand("Cancel", ClusterGeneralModel.this); //$NON-NLS-1$
-                command.setTitle(ConstantsManager.getInstance().getConstants().close());
-                command.setIsCancel(true);
-                glusterSwiftModel.getCommands().add(command);
-            }
+            command = new UICommand("Cancel", ClusterGeneralModel.this); //$NON-NLS-1$
+            command.setTitle(ConstantsManager.getInstance().getConstants().close());
+            command.setIsCancel(true);
+            glusterSwiftModel.getCommands().add(command);
         }), cluster.getId());
     }
 
@@ -316,7 +299,7 @@ public class ClusterGeneralModel extends EntityModel<Cluster> {
         ManageGlusterSwiftModel glusterSwiftModel = (ManageGlusterSwiftModel) getWindow();
         glusterSwiftModel.startProgress();
         if (glusterSwiftModel.getIsManageServerLevel().getEntity()) {
-            ArrayList<VdcActionParametersBase> parametersList = new ArrayList<>();
+            ArrayList<ActionParametersBase> parametersList = new ArrayList<>();
             for (Object model : glusterSwiftModel.getHostServicesList().getItems()) {
                 GlusterSwiftServiceModel swiftServiceModel = (GlusterSwiftServiceModel) model;
                 GlusterSwiftAction action =
@@ -337,17 +320,14 @@ public class ClusterGeneralModel extends EntityModel<Cluster> {
             // becuase this flag is now supported.
             // should check what is the required behaviour and return to true if required.
             if (!parametersList.isEmpty()) {
-                Frontend.getInstance().runMultipleAction(VdcActionType.ManageGlusterService,
+                Frontend.getInstance().runMultipleAction(ActionType.ManageGlusterService,
                         parametersList,
                         false,
-                        new IFrontendMultipleActionAsyncCallback() {
-                            @Override
-                            public void executed(FrontendMultipleActionAsyncResult result) {
-                                ManageGlusterSwiftModel innerGlusterSwiftModel = (ManageGlusterSwiftModel) result.getState();
-                                innerGlusterSwiftModel.stopProgress();
-                                cancel();
-                                updateGlusterDetails();
-                            }
+                        result -> {
+                            ManageGlusterSwiftModel innerGlusterSwiftModel = (ManageGlusterSwiftModel) result.getState();
+                            innerGlusterSwiftModel.stopProgress();
+                            cancel();
+                            updateGlusterDetails();
                         },
                         glusterSwiftModel);
             }
@@ -369,15 +349,12 @@ public class ClusterGeneralModel extends EntityModel<Cluster> {
                                 null,
                                 ServiceType.GLUSTER_SWIFT,
                                 action.name().toLowerCase());
-                Frontend.getInstance().runAction(VdcActionType.ManageGlusterService, parameters, new IFrontendActionAsyncCallback() {
-                    @Override
-                    public void executed(FrontendActionAsyncResult result) {
-                        ManageGlusterSwiftModel innerGlusterSwiftModel = (ManageGlusterSwiftModel) result.getState();
-                        innerGlusterSwiftModel.stopProgress();
-                        if (result.getReturnValue().getSucceeded()) {
-                            cancel();
-                            updateGlusterDetails();
-                        }
+                Frontend.getInstance().runAction(ActionType.ManageGlusterService, parameters, result -> {
+                    ManageGlusterSwiftModel innerGlusterSwiftModel = (ManageGlusterSwiftModel) result.getState();
+                    innerGlusterSwiftModel.stopProgress();
+                    if (result.getReturnValue().getSucceeded()) {
+                        cancel();
+                        updateGlusterDetails();
                     }
                 }, glusterSwiftModel);
             }
@@ -423,25 +400,22 @@ public class ClusterGeneralModel extends EntityModel<Cluster> {
 
         hostsModel.startProgress();
 
-        AsyncDataProvider.getInstance().getGlusterHostsNewlyAdded(new AsyncQuery<>(new AsyncCallback<Map<String, String>>() {
-            @Override
-            public void onSuccess(Map<String, String> hostMap) {
-                if (hostMap == null || hostMap.isEmpty()) {
-                    hostsModel.setMessage(ConstantsManager.getInstance().getConstants().emptyNewGlusterHosts());
-                }
-                else {
-                    ArrayList<EntityModel<HostDetailModel>> list = new ArrayList<>();
-                    for (Map.Entry<String, String> host : hostMap.entrySet()) {
-                        HostDetailModel hostModel = new HostDetailModel(host.getKey(), host.getValue());
-                        hostModel.setName(host.getKey());
-                        hostModel.setPassword("");//$NON-NLS-1$
-                        EntityModel<HostDetailModel> entityModel = new EntityModel<>(hostModel);
-                        list.add(entityModel);
-                    }
-                    hostsModel.getHosts().setItems(list);
-                }
-                hostsModel.stopProgress();
+        AsyncDataProvider.getInstance().getGlusterHostsNewlyAdded(new AsyncQuery<>(hostMap -> {
+            if (hostMap == null || hostMap.isEmpty()) {
+                hostsModel.setMessage(ConstantsManager.getInstance().getConstants().emptyNewGlusterHosts());
             }
+            else {
+                ArrayList<EntityModel<HostDetailModel>> list = new ArrayList<>();
+                for (Map.Entry<String, String> host : hostMap.entrySet()) {
+                    HostDetailModel hostModel = new HostDetailModel(host.getKey(), host.getValue());
+                    hostModel.setName(host.getKey());
+                    hostModel.setPassword("");//$NON-NLS-1$
+                    EntityModel<HostDetailModel> entityModel = new EntityModel<>(hostModel);
+                    list.add(entityModel);
+                }
+                hostsModel.getHosts().setItems(list);
+            }
+            hostsModel.stopProgress();
         }), getEntity().getId(), true);
 
     }
@@ -456,7 +430,7 @@ public class ClusterGeneralModel extends EntityModel<Cluster> {
         }
 
         hostsModel.startProgress();
-        ArrayList<VdcActionParametersBase> parametersList = new ArrayList<>();
+        ArrayList<ActionParametersBase> parametersList = new ArrayList<>();
         for (Object object : hostsModel.getHosts().getItems()) {
             HostDetailModel hostDetailModel = (HostDetailModel) ((EntityModel) object).getEntity();
 
@@ -482,26 +456,22 @@ public class ClusterGeneralModel extends EntityModel<Cluster> {
         // Todo: calling the runMultipleAction() with isRunOnlyIfAllValidationPass=false
         // becuase this flag is now supported.
         // should check what is the required behaviour and return to true if required.
-        Frontend.getInstance().runMultipleAction(VdcActionType.AddVds,
+        Frontend.getInstance().runMultipleAction(ActionType.AddVds,
                 parametersList,
                 false,
-                new IFrontendMultipleActionAsyncCallback() {
-
-                    @Override
-                    public void executed(FrontendMultipleActionAsyncResult result) {
-                        hostsModel.stopProgress();
-                        boolean isAllValidatePassed = true;
-                        for (VdcReturnValueBase returnValueBase : result.getReturnValue()) {
-                            isAllValidatePassed = isAllValidatePassed && returnValueBase.isValid();
-                            if (!isAllValidatePassed) {
-                                break;
-                            }
-                        }
-                        if (isAllValidatePassed) {
-                            updateAlerts();
-                            cancel();
+                result -> {
+                    hostsModel.stopProgress();
+                    boolean isAllValidatePassed = true;
+                    for (ActionReturnValue returnValueBase : result.getReturnValue()) {
+                        isAllValidatePassed = isAllValidatePassed && returnValueBase.isValid();
+                        if (!isAllValidatePassed) {
+                            break;
                         }
                     }
+                    if (isAllValidatePassed) {
+                        updateAlerts();
+                        cancel();
+                    }
                 }, null);
     }
 
@@ -524,21 +494,18 @@ public class ClusterGeneralModel extends EntityModel<Cluster> {
 
         hostsModel.startProgress();
 
-        AsyncDataProvider.getInstance().getGlusterHostsNewlyAdded(new AsyncQuery<>(new AsyncCallback<Map<String, String>>() {
-            @Override
-            public void onSuccess(Map<String, String> hostMap) {
-                if (hostMap == null || hostMap.isEmpty()) {
-                    hostsModel.setMessage(ConstantsManager.getInstance().getConstants().emptyNewGlusterHosts());
-                }
-                else {
-                    ArrayList<EntityModel<String>> hostList = new ArrayList<>();
-                    for (String host : hostMap.keySet()) {
-                        hostList.add(new EntityModel<>(host));
-                    }
-                    hostsModel.getHosts().setItems(hostList);
-                }
-                hostsModel.stopProgress();
+        AsyncDataProvider.getInstance().getGlusterHostsNewlyAdded(new AsyncQuery<>(hostMap -> {
+            if (hostMap == null || hostMap.isEmpty()) {
+                hostsModel.setMessage(ConstantsManager.getInstance().getConstants().emptyNewGlusterHosts());
             }
+            else {
+                ArrayList<EntityModel<String>> hostList = new ArrayList<>();
+                for (String host : hostMap.keySet()) {
+                    hostList.add(new EntityModel<>(host));
+                }
+                hostsModel.getHosts().setItems(hostList);
+            }
+            hostsModel.stopProgress();
         }), getEntity().getId(), true);
     }
 
@@ -552,12 +519,12 @@ public class ClusterGeneralModel extends EntityModel<Cluster> {
             return;
         }
         boolean force = hostsModel.getForce().getEntity();
-        ArrayList<VdcActionParametersBase> parametersList = new ArrayList<>();
+        ArrayList<ActionParametersBase> parametersList = new ArrayList<>();
         for (Object model : hostsModel.getHosts().getSelectedItems()) {
             String host = (String) ((EntityModel) model).getEntity();
             parametersList.add(new RemoveGlusterServerParameters(getEntity().getId(), host, force));
         }
-        Frontend.getInstance().runMultipleAction(VdcActionType.RemoveGlusterServer, parametersList);
+        Frontend.getInstance().runMultipleAction(ActionType.RemoveGlusterServer, parametersList);
         cancel();
     }
 
@@ -567,53 +534,44 @@ public class ClusterGeneralModel extends EntityModel<Cluster> {
 
 
     private void updateGlusterDetails() {
-        AsyncDataProvider.getInstance().getVolumeList(new AsyncQuery<>(new AsyncCallback<List<GlusterVolumeEntity>>() {
-            @Override
-            public void onSuccess(List<GlusterVolumeEntity> volumeList) {
-                int volumesUp = 0;
-                int volumesDown = 0;
-                for (GlusterVolumeEntity volumeEntity : volumeList) {
-                    if (volumeEntity.getStatus() == GlusterStatus.UP) {
-                        volumesUp++;
-                    }
-                    else {
-                        volumesDown++;
-                    }
+        AsyncDataProvider.getInstance().getVolumeList(new AsyncQuery<>(volumeList -> {
+            int volumesUp = 0;
+            int volumesDown = 0;
+            for (GlusterVolumeEntity volumeEntity : volumeList) {
+                if (volumeEntity.getStatus() == GlusterStatus.UP) {
+                    volumesUp++;
+                }
+                else {
+                    volumesDown++;
                 }
-                setNoOfVolumesTotal(volumeList.size());
-                setNoOfVolumesUp(volumesUp);
-                setNoOfVolumesDown(volumesDown);
             }
+            setNoOfVolumesTotal(volumeList.size());
+            setNoOfVolumesUp(volumesUp);
+            setNoOfVolumesDown(volumesDown);
         }), getEntity().getName());
 
         getManageGlusterSwiftCommand().setIsExecutionAllowed(getGlusterSwiftStatus() != GlusterServiceStatus.NOT_AVAILABLE);
 
-        AsyncDataProvider.getInstance().getClusterGlusterSwiftService(new AsyncQuery<>(new AsyncCallback<GlusterClusterService>() {
-            @Override
-            public void onSuccess(GlusterClusterService swiftService) {
-                if(swiftService != null) {
-                    setGlusterSwiftStatus(swiftService.getStatus());
-                }
-                else {
-                    setGlusterSwiftStatus(GlusterServiceStatus.UNKNOWN);
-                }
+        AsyncDataProvider.getInstance().getClusterGlusterSwiftService(new AsyncQuery<>(swiftService -> {
+            if(swiftService != null) {
+                setGlusterSwiftStatus(swiftService.getStatus());
+            }
+            else {
+                setGlusterSwiftStatus(GlusterServiceStatus.UNKNOWN);
             }
         }), getEntity().getId());
     }
 
     private void updateAlerts() {
         if (getEntity().supportsGlusterService()) {
-            AsyncDataProvider.getInstance().getGlusterHostsNewlyAdded(new AsyncQuery<>(new AsyncCallback<Map<String, String>>() {
-                @Override
-                public void onSuccess(Map<String, String> serverMap) {
-                    if (!serverMap.isEmpty()) {
-                        setHasNewGlusterHostsAlert(true);
-                        setHasAnyAlert(true);
-                    }
-                    else {
-                        setHasNewGlusterHostsAlert(false);
-                        setHasAnyAlert(false);
-                    }
+            AsyncDataProvider.getInstance().getGlusterHostsNewlyAdded(new AsyncQuery<>(serverMap -> {
+                if (!serverMap.isEmpty()) {
+                    setHasNewGlusterHostsAlert(true);
+                    setHasAnyAlert(true);
+                }
+                else {
+                    setHasNewGlusterHostsAlert(false);
+                    setHasAnyAlert(false);
                 }
             }), getEntity().getId(), false);
         }
