@@ -4,14 +4,13 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 
-import org.ovirt.engine.core.common.businessentities.StoragePool;
 import org.ovirt.engine.core.common.businessentities.VmTemplate;
 import org.ovirt.engine.core.common.businessentities.storage.Disk;
 import org.ovirt.engine.core.common.businessentities.storage.DiskImage;
 import org.ovirt.engine.core.common.interfaces.SearchType;
+import org.ovirt.engine.core.common.queries.QueryReturnValue;
+import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.core.common.queries.SearchParameters;
-import org.ovirt.engine.core.common.queries.VdcQueryReturnValue;
-import org.ovirt.engine.core.common.queries.VdcQueryType;
 import org.ovirt.engine.core.compat.Guid;
 import org.ovirt.engine.ui.frontend.AsyncCallback;
 import org.ovirt.engine.ui.frontend.Frontend;
@@ -75,12 +74,12 @@ public class ImportTemplateModel extends ImportVmFromExportDomainModel {
     }
 
     public void init(final Collection<VmTemplate> externalTemplates, final Guid storageDomainId) {
-        Frontend.getInstance().runQuery(VdcQueryType.Search,
+        Frontend.getInstance().runQuery(QueryType.Search,
                 new SearchParameters(createSearchPattern(externalTemplates), SearchType.VmTemplate),
-                new AsyncQuery<>(new AsyncCallback<VdcQueryReturnValue>() {
+                new AsyncQuery<>(new AsyncCallback<QueryReturnValue>() {
 
                     @Override
-                    public void onSuccess(VdcQueryReturnValue returnValue) {
+                    public void onSuccess(QueryReturnValue returnValue) {
                         UIConstants constants = ConstantsManager.getInstance().getConstants();
                         List<VmTemplate> vmtList = returnValue.getReturnValue();
 
@@ -97,12 +96,7 @@ public class ImportTemplateModel extends ImportVmFromExportDomainModel {
                             templateDataList.add(templateData);
                         }
                         setItems(templateDataList);
-                        withDataCenterLoaded(storageDomainId, new AsyncCallback<List<StoragePool>>() {
-                            @Override
-                            public void onSuccess(List<StoragePool> returnValue) {
-                                doInit();
-                            }
-                        });
+                        withDataCenterLoaded(storageDomainId, r -> doInit());
                     }
 
                     private VmTemplate findAnyVmTemplateById(List<VmTemplate> vmtList, Guid templateId) {
