@@ -3,22 +3,20 @@ package org.ovirt.engine.ui.uicommonweb.models.templates;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.List;
 
+import org.ovirt.engine.core.common.action.ActionParametersBase;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.RemoveDiskParameters;
-import org.ovirt.engine.core.common.action.VdcActionParametersBase;
-import org.ovirt.engine.core.common.action.VdcActionType;
 import org.ovirt.engine.core.common.businessentities.StorageDomain;
 import org.ovirt.engine.core.common.businessentities.VmTemplate;
 import org.ovirt.engine.core.common.businessentities.comparators.DiskByDiskAliasComparator;
 import org.ovirt.engine.core.common.businessentities.storage.DiskImage;
 import org.ovirt.engine.core.common.businessentities.storage.ImageStatus;
 import org.ovirt.engine.core.common.queries.IdQueryParameters;
-import org.ovirt.engine.core.common.queries.VdcQueryType;
-import org.ovirt.engine.ui.frontend.AsyncCallback;
+import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.ui.frontend.Frontend;
-import org.ovirt.engine.ui.uicommonweb.Linq;
-import org.ovirt.engine.ui.uicommonweb.Linq.StorageDomainModelByNameComparer;
 import org.ovirt.engine.ui.uicommonweb.UICommand;
 import org.ovirt.engine.ui.uicommonweb.dataprovider.AsyncDataProvider;
 import org.ovirt.engine.ui.uicommonweb.help.HelpTag;
@@ -28,8 +26,6 @@ import org.ovirt.engine.ui.uicommonweb.models.storage.StorageDomainModel;
 import org.ovirt.engine.ui.uicommonweb.models.vms.DiskModel;
 import org.ovirt.engine.ui.uicompat.ConstantsManager;
 import org.ovirt.engine.ui.uicompat.EventArgs;
-import org.ovirt.engine.ui.uicompat.FrontendMultipleActionAsyncResult;
-import org.ovirt.engine.ui.uicompat.IFrontendMultipleActionAsyncCallback;
 import org.ovirt.engine.ui.uicompat.PropertyChangedEventArgs;
 
 public class TemplateStorageListModel extends SearchableListModel<VmTemplate, StorageDomainModel> {
@@ -76,14 +72,14 @@ public class TemplateStorageListModel extends SearchableListModel<VmTemplate, St
         super.syncSearch();
 
         VmTemplate template = getEntity();
-        super.syncSearch(VdcQueryType.GetStorageDomainsByVmTemplateId,
+        super.syncSearch(QueryType.GetStorageDomainsByVmTemplateId,
                 new IdQueryParameters(template.getId()));
     }
 
     @Override
     public void setItems(final Collection<StorageDomainModel> value) {
         if (storageDomainModels != null) {
-            Collections.sort(storageDomainModels, new StorageDomainModelByNameComparer());
+            Collections.sort(storageDomainModels, Comparator.comparing(s -> s.getStorageDomain().getStorageName()));
             itemsChanging(value, items);
             items = storageDomainModels;
             itemsChanged();
@@ -94,34 +90,31 @@ public class TemplateStorageListModel extends SearchableListModel<VmTemplate, St
         else {
             VmTemplate template = getEntity();
             AsyncDataProvider.getInstance().getTemplateDiskList(new AsyncQuery<>(
-                    new AsyncCallback<List<DiskImage>>() {
-                        @SuppressWarnings("unchecked")
-                        @Override
-                        public void onSuccess(List<DiskImage> diskImages) {
+                            diskImages -> {
 
-                            List<StorageDomain> storageDomains = Linq.cast(value);
-                            List<StorageDomainModel> storageDomainModels = new ArrayList<>();
+                                Collection<? extends Object> storageDomains = value;
+                                List<StorageDomainModel> storageDomainModels = new ArrayList<>();
 
-                            for (StorageDomain storageDomain : storageDomains) {
-                                StorageDomainModel storageDomainModel = new StorageDomainModel();
-                                storageDomainModel.setStorageDomain(storageDomain);
+                                for (Object o : storageDomains) {
+                                    StorageDomain storageDomain = (StorageDomain) o;
+                                    StorageDomainModel storageDomainModel = new StorageDomainModel();
+                                    storageDomainModel.setStorageDomain(storageDomain);
 
-                                ArrayList<DiskImage> disks = new ArrayList<>();
-                                for (DiskImage diskImage : diskImages) {
-                                    if (diskImage.getStorageIds().contains(storageDomain.getId())) {
-                                        disks.add(diskImage);
+                                    ArrayList<DiskImage> disks = new ArrayList<>();
+                                    for (DiskImage diskImage : diskImages) {
+                                        if (diskImage.getStorageIds().contains(storageDomain.getId())) {
+                                            disks.add(diskImage);
+                                        }
                                     }
+
+                                    Collections.sort(disks, new DiskByDiskAliasComparator());
+                                    storageDomainModel.setDisks(disks);
+                                    storageDomainModels.add(storageDomainModel);
                                 }
 
-                                Collections.sort(disks, new DiskByDiskAliasComparator());
-                                storageDomainModel.setDisks(disks);
-                                storageDomainModels.add(storageDomainModel);
-                            }
-
-                            TemplateStorageListModel.this.storageDomainModels = storageDomainModels;
-                            setItems(value);
-                        }
-                    }),
+                                TemplateStorageListModel.this.storageDomainModels = storageDomainModels;
+                                setItems(value);
+                            }),
                     template.getId());
         }
     }
@@ -137,10 +130,10 @@ public class TemplateStorageListModel extends SearchableListModel<VmTemplate, St
         model.setHelpTag(HelpTag.remove_template_disks);
         model.setHashName("remove_template_disks"); //$NON-NLS-1$
 
-        List<DiskModel> disks =
-                getSelectedItems() != null ? Linq.<DiskModel> cast(getSelectedItems()) : new ArrayList<DiskModel>();
+        List<? extends Object> disks = getSelectedItems() != null ? getSelectedItems() : new ArrayList<DiskModel>();
         List<String> items = new ArrayList<>();
-        for (DiskModel diskModel : disks) {
+        for (Object o : disks) {
+            DiskModel diskModel = (DiskModel) o;
             items.add(ConstantsManager.getInstance().getMessages().templateDiskDescription(
                     diskModel.getDisk().getDiskAlias(),
                     diskModel.getStorageDomain().getSelectedItem().getStorageName()));
@@ -155,27 +148,24 @@ public class TemplateStorageListModel extends SearchableListModel<VmTemplate, St
 
     private void onRemove() {
         ConfirmationModel model = (ConfirmationModel) getWindow();
-        List<VdcActionParametersBase> parameters = new ArrayList<>();
-        List<DiskModel> disks =
-                getSelectedItems() != null ? Linq.<DiskModel> cast(getSelectedItems()) : new ArrayList<DiskModel>();
+        List<ActionParametersBase> parameters = new ArrayList<>();
+        List<? extends Object> disks = getSelectedItems() != null ? getSelectedItems() : new ArrayList<DiskModel>();
 
-        for (DiskModel diskModel: disks) {
-                RemoveDiskParameters params =
+        for (Object o: disks) {
+            DiskModel diskModel = (DiskModel) o;
+            RemoveDiskParameters params =
                     new RemoveDiskParameters(diskModel.getDisk().getId(),
                                              diskModel.getStorageDomain().getSelectedItem().getId());
-                parameters.add(params);
+            parameters.add(params);
         }
 
         model.startProgress();
 
-        Frontend.getInstance().runMultipleAction(VdcActionType.RemoveDisk, parameters,
-                new IFrontendMultipleActionAsyncCallback() {
-                    @Override
-                    public void executed(FrontendMultipleActionAsyncResult result) {
-                        ConfirmationModel localModel = (ConfirmationModel) result.getState();
-                        localModel.stopProgress();
-                        cancel();
-                    }
+        Frontend.getInstance().runMultipleAction(ActionType.RemoveDisk, parameters,
+                result -> {
+                    ConfirmationModel localModel = (ConfirmationModel) result.getState();
+                    localModel.stopProgress();
+                    cancel();
                 }, model);
 
         cancel();
@@ -205,14 +195,14 @@ public class TemplateStorageListModel extends SearchableListModel<VmTemplate, St
     }
 
     private boolean isRemoveCommandAvailable() {
-        ArrayList<DiskModel> disks =
-                getSelectedItems() != null ? Linq.<DiskModel> cast(getSelectedItems()) : new ArrayList<DiskModel>();
+        List<? extends Object> disks = getSelectedItems() != null ? getSelectedItems() : new ArrayList<DiskModel>();
 
         if (disks.isEmpty()) {
             return false;
         }
 
-        for (DiskModel disk : disks) {
+        for (Object o: disks) {
+            DiskModel disk = (DiskModel) o;
             if (((DiskImage) disk.getDisk()).getImageStatus() == ImageStatus.LOCKED
                     || ((DiskImage) disk.getDisk()).getStorageIds().size() == 1) {
                 return false;
