@@ -2,11 +2,10 @@ package org.ovirt.engine.ui.uicommonweb.models.vms;
 
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.List;
 
-import org.ovirt.engine.core.common.action.VdcActionParametersBase;
-import org.ovirt.engine.core.common.action.VdcActionType;
-import org.ovirt.engine.core.common.action.VdcReturnValueBase;
+import org.ovirt.engine.core.common.action.ActionParametersBase;
+import org.ovirt.engine.core.common.action.ActionReturnValue;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.businessentities.VMStatus;
 import org.ovirt.engine.core.common.businessentities.VmBase;
 import org.ovirt.engine.core.common.businessentities.network.Network;
@@ -15,7 +14,6 @@ import org.ovirt.engine.core.common.businessentities.network.VmNetworkInterface;
 import org.ovirt.engine.core.common.businessentities.network.VnicProfileView;
 import org.ovirt.engine.core.compat.Guid;
 import org.ovirt.engine.core.compat.Version;
-import org.ovirt.engine.ui.frontend.AsyncCallback;
 import org.ovirt.engine.ui.frontend.Frontend;
 import org.ovirt.engine.ui.uicommonweb.UICommand;
 import org.ovirt.engine.ui.uicommonweb.dataprovider.AsyncDataProvider;
@@ -31,8 +29,6 @@ import org.ovirt.engine.ui.uicommonweb.validation.VnicProfileValidation;
 import org.ovirt.engine.ui.uicompat.ConstantsManager;
 import org.ovirt.engine.ui.uicompat.Event;
 import org.ovirt.engine.ui.uicompat.EventArgs;
-import org.ovirt.engine.ui.uicompat.FrontendActionAsyncResult;
-import org.ovirt.engine.ui.uicompat.IFrontendActionAsyncCallback;
 import org.ovirt.engine.ui.uicompat.PropertyChangedEventArgs;
 
 public abstract class VmInterfaceModel extends Model {
@@ -66,6 +62,8 @@ public abstract class VmInterfaceModel extends Model {
 
     private Guid dcId;
 
+    private ListModel<NetworkFilterParameterModel> networkFilterParameterListModel;
+
     protected VmInterfaceModel(VmBase vm,
             VMStatus vmStatus,
             Guid dcId,
@@ -133,6 +131,7 @@ public abstract class VmInterfaceModel extends Model {
         setUnplugged_IsSelected(new EntityModel<Boolean>());
         getUnplugged_IsSelected().getEntityChangedEvent().addListener(this);
 
+        setNetworkFilterParameterListModel(new ListModel<NetworkFilterParameterModel>());
     }
 
     protected abstract void init();
@@ -254,6 +253,14 @@ public abstract class VmInterfaceModel extends Model {
         unplugged_IsSelected = value;
     }
 
+    public ListModel<NetworkFilterParameterModel> getNetworkFilterParameterListModel() {
+        return networkFilterParameterListModel;
+    }
+
+    public void setNetworkFilterParameterListModel(ListModel<NetworkFilterParameterModel> networkFilterParameterListModel) {
+        this.networkFilterParameterListModel = networkFilterParameterListModel;
+    }
+
     @Override
     public void eventRaised(Event<? extends EventArgs> ev, Object sender, EventArgs args) {
         super.eventRaised(ev, sender, args);
@@ -272,11 +279,11 @@ public abstract class VmInterfaceModel extends Model {
 
                 boolean isPlugChangeable = getPlugged().getIsChangable();
 
-                getPlugged_IsSelected().setChangeProhibitionReason(getLinked().getChangeProhibitionReason());
                 getPlugged_IsSelected().setIsChangeable(isPlugChangeable);
+                getPlugged_IsSelected().setChangeProhibitionReason(getLinked().getChangeProhibitionReason());
 
-                getUnplugged_IsSelected().setChangeProhibitionReason(getLinked().getChangeProhibitionReason());
                 getUnplugged_IsSelected().setIsChangeable(isPlugChangeable);
+                getUnplugged_IsSelected().setChangeProhibitionReason(getLinked().getChangeProhibitionReason());
             } else if (propArgs.propertyName.equals("IsAvailable")) { //$NON-NLS-1$
                 boolean isPlugAvailable = getPlugged().getIsAvailable();
                 getPlugged_IsSelected().setIsAvailable(isPlugAvailable);
@@ -303,11 +310,11 @@ public abstract class VmInterfaceModel extends Model {
             } else if (propArgs.propertyName.equals("IsChangable")) { //$NON-NLS-1$
                 boolean isLinkedChangeable = getLinked().getIsChangable();
 
-                getLinked_IsSelected().setChangeProhibitionReason(getLinked().getChangeProhibitionReason());
                 getLinked_IsSelected().setIsChangeable(isLinkedChangeable);
+                getLinked_IsSelected().setChangeProhibitionReason(getLinked().getChangeProhibitionReason());
 
-                getUnlinked_IsSelected().setChangeProhibitionReason(getLinked().getChangeProhibitionReason());
                 getUnlinked_IsSelected().setIsChangeable(isLinkedChangeable);
+                getUnlinked_IsSelected().setChangeProhibitionReason(getLinked().getChangeProhibitionReason());
             } else if (propArgs.propertyName.equals("IsAvailable")) { //$NON-NLS-1$
                 boolean isLinkedAvailable = getLinked().getIsAvailable();
                 getLinked_IsSelected().setIsAvailable(isLinkedAvailable);
@@ -344,8 +351,20 @@ public abstract class VmInterfaceModel extends Model {
             getMAC().validateEntity(new IValidation[] { new NotEmptyValidation(), new UnicastMacAddressValidation() });
         }
 
+        validateNetworkFilterParameters();
+
         return getName().getIsValid() && getNicType().getIsValid()
-                && getMAC().getIsValid() && getProfile().getIsValid();
+                && getMAC().getIsValid() && getProfile().getIsValid()
+                && getNetworkFilterParameterListModel().getIsValid();
+    }
+
+    private void validateNetworkFilterParameters() {
+        boolean valid = true;
+        for (NetworkFilterParameterModel model : getNetworkFilterParameterListModel().getItems()) {
+            model.validate();
+            valid &= model.getIsValid();
+        }
+        getNetworkFilterParameterListModel().setIsValid(valid);
     }
 
     protected abstract VmNetworkInterface createBaseNic();
@@ -379,18 +398,14 @@ public abstract class VmInterfaceModel extends Model {
 
         startProgress();
 
-        Frontend.getInstance().runAction(getVdcActionType(),
+        Frontend.getInstance().runAction(getActionType(),
                 createVdcActionParameters(nic),
-                new IFrontendActionAsyncCallback() {
-                    @Override
-                    public void executed(FrontendActionAsyncResult result) {
-                        VdcReturnValueBase returnValue = result.getReturnValue();
-                        stopProgress();
-
-                        if (returnValue != null && returnValue.getSucceeded()) {
-                            cancel();
-                            postOnSave();
-                        }
+                result -> {
+                    ActionReturnValue returnValue = result.getReturnValue();
+                    stopProgress();
+                    if (returnValue != null && returnValue.getSucceeded()) {
+                        cancel();
+                        postOnSave();
                     }
                 },
                 this);
@@ -406,21 +421,18 @@ public abstract class VmInterfaceModel extends Model {
 
     protected abstract String getDefaultMacAddress();
 
-    protected abstract VdcActionType getVdcActionType();
+    protected abstract ActionType getActionType();
 
     protected void initProfiles() {
-        profileBehavior.initProfiles(getVm().getClusterId(), dcId, new AsyncQuery<>(new AsyncCallback<List<VnicProfileView>>() {
-            @Override
-            public void onSuccess(List<VnicProfileView> result) {
-                getProfile().setItems(result);
-                profileBehavior.initSelectedProfile(getProfile(), getNic());
-                updateProfileChangability();
+        profileBehavior.initProfiles(getVm().getClusterId(), dcId, new AsyncQuery<>(result -> {
+            getProfile().setItems(result);
+            profileBehavior.initSelectedProfile(getProfile(), getNic());
+            updateProfileChangability();
 
-                // fetch completed
-                okCommand.setIsExecutionAllowed(true);
+            // fetch completed
+            okCommand.setIsExecutionAllowed(true);
 
-                initSelectedType();
-            }
+            initSelectedType();
         }));
     }
 
@@ -458,7 +470,7 @@ public abstract class VmInterfaceModel extends Model {
                 : getMAC().getEntity().toLowerCase() : getDefaultMacAddress());
     }
 
-    protected abstract VdcActionParametersBase createVdcActionParameters(VmNetworkInterface nicToSave);
+    protected abstract ActionParametersBase createVdcActionParameters(VmNetworkInterface nicToSave);
 
     protected void updateLinkChangability() {
         boolean isNullProfileSelected = getProfile().getSelectedItem() == null;
