@@ -2,21 +2,18 @@ package org.ovirt.engine.ui.webadmin.section.main.view.tab.template;
 
 import org.ovirt.engine.core.common.businessentities.VmTemplate;
 import org.ovirt.engine.ui.common.uicommon.model.SearchableDetailModelProvider;
-import org.ovirt.engine.ui.common.widget.action.SubTabTreeActionPanel;
-import org.ovirt.engine.ui.common.widget.action.UiCommandButtonDefinition;
 import org.ovirt.engine.ui.common.widget.table.column.EmptyColumn;
 import org.ovirt.engine.ui.common.widget.table.header.ImageResourceHeader;
-import org.ovirt.engine.ui.uicommonweb.UICommand;
 import org.ovirt.engine.ui.uicommonweb.models.templates.TemplateDiskListModel;
 import org.ovirt.engine.ui.uicommonweb.models.templates.TemplateListModel;
 import org.ovirt.engine.ui.uicommonweb.models.vms.DiskModel;
 import org.ovirt.engine.ui.webadmin.ApplicationConstants;
 import org.ovirt.engine.ui.webadmin.ApplicationResources;
 import org.ovirt.engine.ui.webadmin.gin.AssetProvider;
-import org.ovirt.engine.ui.webadmin.gin.ClientGinjectorProvider;
 import org.ovirt.engine.ui.webadmin.section.main.presenter.tab.template.SubTabTemplateDiskPresenter;
 import org.ovirt.engine.ui.webadmin.section.main.view.AbstractSubTabTreeView;
 import org.ovirt.engine.ui.webadmin.widget.template.DisksTree;
+
 import com.google.gwt.event.shared.EventBus;
 import com.google.gwt.safehtml.shared.SafeHtmlUtils;
 import com.google.inject.Inject;
@@ -30,22 +27,6 @@ public class SubTabTemplateDiskView extends AbstractSubTabTreeView<DisksTree, Vm
     public SubTabTemplateDiskView(final SearchableDetailModelProvider<DiskModel, TemplateListModel, TemplateDiskListModel> modelProvider,
             EventBus eventBus) {
         super(modelProvider);
-
-        actionPanel.addActionButton(new UiCommandButtonDefinition<DiskModel>(eventBus, constants.copyDisk()) {
-            @Override
-            protected UICommand resolveCommand() {
-                return modelProvider.getModel().getCopyCommand();
-            }
-        });
-
-        actionPanel.addActionButton(new UiCommandButtonDefinition<DiskModel>(eventBus, constants.assignQuota()) {
-            @Override
-            protected UICommand resolveCommand() {
-                return modelProvider.getModel().getChangeQuotaCommand();
-            }
-        });
-
-        setIsActionTree(true);
     }
 
     @Override
@@ -60,16 +41,12 @@ public class SubTabTemplateDiskView extends AbstractSubTabTreeView<DisksTree, Vm
         table.addColumn(new EmptyColumn(), constants.allocationDisk(), "120px"); //$NON-NLS-1$
         table.addColumn(new EmptyColumn(), constants.interfaceDisk(), "120px"); //$NON-NLS-1$
         table.addColumn(new EmptyColumn(), constants.typeDisk(), "120px"); //$NON-NLS-1$
-        table.addColumn(new EmptyColumn(), constants.creationDateDisk(), "120px"); //$NON-NLS-1$
+        table.addColumn(new EmptyColumn(), constants.creationDateDisk(), "150px"); //$NON-NLS-1$
+        table.setHeight("30px"); // $NON-NLS-1$
     }
 
     @Override
     protected DisksTree getTree() {
         return new DisksTree();
     }
-
-    @Override
-    protected SubTabTreeActionPanel createActionPanel(SearchableDetailModelProvider modelProvider) {
-        return new SubTabTreeActionPanel<>(modelProvider, ClientGinjectorProvider.getEventBus());
-    }
 }
